# pure python implimentation of lib.c script to replace nans 


import numpy as np


def replace_nans(array, max_iter, tol, kernel_size=2, method="disk"):

    """Replace NaN elements in an array using an iterative image inpainting algorithm.

      The algorithm is the following:

      1) For each element in the input array, replace it by a weighted average
         of the neighbouring elements which are not NaN themselves. The weights
         depend on the method type. See Methods below.

      2) Several iterations are needed if there are adjacent NaN elements.
         If this is the case, information is "spread" from the edges of the missing
         regions iteratively, until the variation is below a certain threshold.

      Methods:

      localmean - A square kernel where all elements have the same value,
                  weights are equal to n/( (2*kernel_size+1)**2 -1 ),
                  where n is the number of non-NaN elements.
      disk - A circular kernel where all elements have the same value,
             kernel is calculated by::
                 if ((S-i)**2 + (S-j)**2)**0.5 <= S:
                     kernel[i,j] = 1.0
                 else:
                     kernel[i,j] = 0.0
             where S is the kernel radius.
      distance - A circular inverse distance kernel where elements are
                 weighted proportional to their distance away from the
                 center of the kernel, elements farther away have less
                 weight. Elements outside the specified radius are set
                 to 0.0 as in 'disk', the remaining of the weights are
                 calculated as::
                     maxDist = ((S)**2 + (S)**2)**0.5
                     kernel[i,j] = -1*(((S-i)**2 + (S-j)**2)**0.5 - maxDist)
                 where S is the kernel radius.

      Parameters
      ----------

      array : 2d or 3d np.ndarray
          an array containing NaN elements that have to be replaced

      max_iter : int
          the number of iterations

      tol : float
          On each iteration check if the mean square difference between
          values of replaced elements is below a certain tolerance `tol`

      kernel_size : int
          the size of the kernel, default is 1

      method : str
          the method used to replace invalid values. Valid options are
          `localmean`, `disk`, and `distance`.

      Returns
      -------

      filled : 2d or 3d np.ndarray
          a copy of the input array, where NaN elements have been replaced.

      """

    kernel_size = int(kernel_size)
    filled = array.copy()
    n_dim = len(array.shape)

    # generating the kernel
    kernel = np.zeros([2 * kernel_size + 1] * len(array.shape), dtype=int)
    if method == "localmean":
        kernel += 1
    elif method == "disk":
        dist, dist_inv = get_dist(kernel, kernel_size)
        kernel[dist <= kernel_size] = 1
    elif method == "distance":
        dist, dist_inv = get_dist(kernel, kernel_size)
        kernel[dist <= kernel_size] = dist_inv[dist <= kernel_size]
    else:
        raise ValueError(
            "method not valid. Should be one of `localmean`, `disk` or `distance`."
        )

    # list of kernel array indices
    # kernel_indices = np.indices(kernel.shape)
    # kernel_indices = np.reshape(kernel_indices, (n_dim, (2 * kernel_size + 1) ** n_dim), order="C").T

    # indices where array is NaN
    nan_indices = np.array(np.nonzero(np.isnan(array))).T.astype(int)

    # number of NaN elements
    n_nans = len(nan_indices)

    # arrays which contain replaced values to check for convergence
    replaced_new = np.zeros(n_nans)
    replaced_old = np.zeros(n_nans)

    # make several passes
    # until we reach convergence
    for it in range(max_iter):
        # note: identifying new nan indices and looping other the new indices would give slightly different result

        # for each NaN element
        for k in range(n_nans):
            ind = nan_indices[
                k
            ]  # 2 or 3 indices indicating the position of a nan element
            # init to 0.0
            replaced_new[k] = 0.0

            # generating a list of indices of the convolution window in the array
            slice_indices = np.array(
                np.meshgrid(*[range(i - kernel_size, i + kernel_size + 1) for i in ind])
            )

            # identifying all indices strictly inside the image edges:
            in_mask = np.array(
                [
                    np.logical_and(
                        slice_indices[i] < array.shape[i], slice_indices[i] >= 0
                    )
                    for i in range(n_dim)
                ]
            )
            # logical and over x,y (and z) indices
            in_mask = np.prod(in_mask, axis=0).astype(bool)

            # extract window from array
            win = filled[tuple(slice_indices[:, in_mask])]

            # selecting the same points from the kernel
            kernel_in = kernel[in_mask]

            # sum of elements of the kernel that are not nan in the window
            non_nan = np.sum(kernel_in[~np.isnan(win)])

            if non_nan > 0:
                # convolution with the kernel
                replaced_new[k] = np.nansum(win * kernel_in) / non_nan
            else:
                # don't do anything if there is only nans around
                replaced_new[k] = np.nan

        # bulk replace all new values in array
        filled[tuple(nan_indices.T)] = replaced_new

        # check if replaced elements are below a certain tolerance
        if np.mean((replaced_new - replaced_old) ** 2) < tol:
            break
        else:
            replaced_old = replaced_new

    return filled


def get_dist(kernel, kernel_size):
    # generates a map of distances to the center of the kernel. This is later used to generate disk-shaped kernels and
    # to fill in distance based weights

    if len(kernel.shape) == 2:
        # x and y coordinates for each points
        xs, ys = np.indices(kernel.shape)
        # maximal distance form center - distance to center (of each point)
        dist = np.sqrt((ys - kernel_size) ** 2 + (xs - kernel_size) ** 2)
        dist_inv = np.sqrt(2) * kernel_size - dist

    if len(kernel.shape) == 3:
        xs, ys, zs = np.indices(kernel.shape)
        dist = np.sqrt(
            (ys - kernel_size) ** 2 + (xs - kernel_size) ** 2 + (zs - kernel_size) ** 2
        )
        dist_inv = np.sqrt(3) * kernel_size - dist

    return dist, dist_inv



#(MIN-env) C:\Users\Asus\Desktop\UI>python C:\Users\Asus\anaconda3\envs\MIN-env\Library\bin\pyside2-uic PIV.ui 
# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'PIV.ui',
# licensing of 'PIV.ui' applies.
#
# Created: Thu Jul  9 10:41:19 2020
#      by: pyside2-uic  running on PySide2 5.13.2
#
# WARNING! All changes made in this file will be lost!

from PySide2 import QtCore, QtGui, QtWidgets

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.setEnabled(True)
        MainWindow.resize(956, 566)
        MainWindow.setContextMenuPolicy(QtCore.Qt.DefaultContextMenu)
        MainWindow.setAcceptDrops(False)
        MainWindow.setWindowOpacity(1.0)
        MainWindow.setAutoFillBackground(False)
        MainWindow.setTabShape(QtWidgets.QTabWidget.Rounded)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.centralwidget)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.Main_tabs = QtWidgets.QTabWidget(self.centralwidget)
        self.Main_tabs.setEnabled(True)
        font = QtGui.QFont()
        font.setPointSize(8)
        font.setWeight(50)
        font.setItalic(False)
        font.setUnderline(False)
        font.setStrikeOut(False)
        font.setBold(False)
        self.Main_tabs.setFont(font)
        self.Main_tabs.setAcceptDrops(False)
        self.Main_tabs.setAccessibleDescription("")
        self.Main_tabs.setAutoFillBackground(False)
        self.Main_tabs.setTabPosition(QtWidgets.QTabWidget.North)
        self.Main_tabs.setTabShape(QtWidgets.QTabWidget.Rounded)
        self.Main_tabs.setElideMode(QtCore.Qt.ElideNone)
        self.Main_tabs.setUsesScrollButtons(True)
        self.Main_tabs.setDocumentMode(False)
        self.Main_tabs.setTabsClosable(False)
        self.Main_tabs.setMovable(False)
        self.Main_tabs.setTabBarAutoHide(False)
        self.Main_tabs.setObjectName("Main_tabs")
        self.Validation = QtWidgets.QWidget()
        self.Validation.setEnabled(True)
        self.Validation.setObjectName("Validation")
        self.gridLayout_4 = QtWidgets.QGridLayout(self.Validation)
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.splitter = QtWidgets.QSplitter(self.Validation)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.splitter.sizePolicy().hasHeightForWidth())
        self.splitter.setSizePolicy(sizePolicy)
        self.splitter.setOrientation(QtCore.Qt.Horizontal)
        self.splitter.setObjectName("splitter")
        self.layoutWidget = QtWidgets.QWidget(self.splitter)
        self.layoutWidget.setObjectName("layoutWidget")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.layoutWidget)
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout.setObjectName("verticalLayout")
        self.settings_GB = QtWidgets.QGroupBox(self.layoutWidget)
        self.settings_GB.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.settings_GB.sizePolicy().hasHeightForWidth())
        self.settings_GB.setSizePolicy(sizePolicy)
        self.settings_GB.setMinimumSize(QtCore.QSize(0, 0))
        font = QtGui.QFont()
        font.setPointSize(8)
        font.setWeight(50)
        font.setItalic(False)
        font.setBold(False)
        self.settings_GB.setFont(font)
        self.settings_GB.setAutoFillBackground(False)
        self.settings_GB.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.settings_GB.setFlat(False)
        self.settings_GB.setCheckable(False)
        self.settings_GB.setChecked(False)
        self.settings_GB.setObjectName("settings_GB")
        self.gridLayout_5 = QtWidgets.QGridLayout(self.settings_GB)
        self.gridLayout_5.setObjectName("gridLayout_5")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.gridLayout = QtWidgets.QGridLayout()
        self.gridLayout.setObjectName("gridLayout")
        self.global_velocity_CB = QtWidgets.QCheckBox(self.settings_GB)
        self.global_velocity_CB.setEnabled(True)
        self.global_velocity_CB.setObjectName("global_velocity_CB")
        self.gridLayout.addWidget(self.global_velocity_CB, 1, 0, 1, 1)
        self.global_uVelocity_LE = QtWidgets.QLineEdit(self.settings_GB)
        self.global_uVelocity_LE.setObjectName("global_uVelocity_LE")
        self.gridLayout.addWidget(self.global_uVelocity_LE, 1, 1, 1, 1)
        self.global_vVelocity_LE = QtWidgets.QLineEdit(self.settings_GB)
        self.global_vVelocity_LE.setObjectName("global_vVelocity_LE")
        self.gridLayout.addWidget(self.global_vVelocity_LE, 1, 2, 1, 1)
        self.local_velocity_CB = QtWidgets.QCheckBox(self.settings_GB)
        self.local_velocity_CB.setEnabled(True)
        self.local_velocity_CB.setObjectName("local_velocity_CB")
        self.gridLayout.addWidget(self.local_velocity_CB, 2, 0, 1, 1)
        self.local_velocity_LE = QtWidgets.QLineEdit(self.settings_GB)
        self.local_velocity_LE.setObjectName("local_velocity_LE")
        self.gridLayout.addWidget(self.local_velocity_LE, 2, 1, 1, 1)
        self.local_kernel_LE = QtWidgets.QLineEdit(self.settings_GB)
        self.local_kernel_LE.setObjectName("local_kernel_LE")
        self.gridLayout.addWidget(self.local_kernel_LE, 2, 2, 1, 1)
        self.s2n_CB = QtWidgets.QCheckBox(self.settings_GB)
        self.s2n_CB.setEnabled(True)
        self.s2n_CB.setObjectName("s2n_CB")
        self.gridLayout.addWidget(self.s2n_CB, 0, 0, 1, 1)
        self.global_std_CB = QtWidgets.QCheckBox(self.settings_GB)
        self.global_std_CB.setEnabled(True)
        self.global_std_CB.setObjectName("global_std_CB")
        self.gridLayout.addWidget(self.global_std_CB, 3, 0, 1, 2)
        self.s2n_LE = QtWidgets.QLineEdit(self.settings_GB)
        self.s2n_LE.setEnabled(True)
        self.s2n_LE.setText("")
        self.s2n_LE.setFrame(True)
        self.s2n_LE.setObjectName("s2n_LE")
        self.gridLayout.addWidget(self.s2n_LE, 0, 2, 1, 1)
        self.global_std_LE = QtWidgets.QLineEdit(self.settings_GB)
        self.global_std_LE.setObjectName("global_std_LE")
        self.gridLayout.addWidget(self.global_std_LE, 3, 2, 1, 1)
        self.verticalLayout_2.addLayout(self.gridLayout)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.apply_settings_PB = QtWidgets.QPushButton(self.settings_GB)
        self.apply_settings_PB.setObjectName("apply_settings_PB")
        self.horizontalLayout.addWidget(self.apply_settings_PB)
        self.load_settings_PB = QtWidgets.QPushButton(self.settings_GB)
        self.load_settings_PB.setObjectName("load_settings_PB")
        self.horizontalLayout.addWidget(self.load_settings_PB)
        self.save_settings_PB = QtWidgets.QPushButton(self.settings_GB)
        self.save_settings_PB.setEnabled(True)
        self.save_settings_PB.setObjectName("save_settings_PB")
        self.horizontalLayout.addWidget(self.save_settings_PB)
        self.verticalLayout_2.addLayout(self.horizontalLayout)
        self.gridLayout_5.addLayout(self.verticalLayout_2, 0, 0, 1, 1)
        self.verticalLayout.addWidget(self.settings_GB)
        self.files_TW = QtWidgets.QTreeWidget(self.layoutWidget)
        self.files_TW.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.files_TW.sizePolicy().hasHeightForWidth())
        self.files_TW.setSizePolicy(sizePolicy)
        self.files_TW.setMinimumSize(QtCore.QSize(0, 0))
        self.files_TW.setAutoScroll(True)
        self.files_TW.setIndentation(0)
        self.files_TW.setItemsExpandable(True)
        self.files_TW.setAnimated(True)
        self.files_TW.setAllColumnsShowFocus(False)
        self.files_TW.setWordWrap(False)
        self.files_TW.setHeaderHidden(False)
        self.files_TW.setObjectName("files_TW")
        self.files_TW.header().setSortIndicatorShown(True)
        self.files_TW.header().setStretchLastSection(True)
        self.verticalLayout.addWidget(self.files_TW)
        self.plot_widget = QtWidgets.QWidget(self.splitter)
        self.plot_widget.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.plot_widget.sizePolicy().hasHeightForWidth())
        self.plot_widget.setSizePolicy(sizePolicy)
        self.plot_widget.setMinimumSize(QtCore.QSize(450, 0))
        self.plot_widget.setAutoFillBackground(False)
        self.plot_widget.setObjectName("plot_widget")
        self.gridLayout_4.addWidget(self.splitter, 0, 0, 1, 1)
        self.Main_tabs.addTab(self.Validation, "")
        self.Process = QtWidgets.QWidget()
        self.Process.setObjectName("Process")
        self.label_4 = QtWidgets.QLabel(self.Process)
        self.label_4.setGeometry(QtCore.QRect(13, 13, 451, 22))
        font = QtGui.QFont()
        font.setPointSize(9)
        self.label_4.setFont(font)
        self.label_4.setObjectName("label_4")
        self.Main_tabs.addTab(self.Process, "")
        self.FrequencyAnalysis = QtWidgets.QWidget()
        self.FrequencyAnalysis.setObjectName("FrequencyAnalysis")
        self.label_5 = QtWidgets.QLabel(self.FrequencyAnalysis)
        self.label_5.setGeometry(QtCore.QRect(13, 13, 431, 22))
        font = QtGui.QFont()
        font.setPointSize(9)
        self.label_5.setFont(font)
        self.label_5.setObjectName("label_5")
        self.Main_tabs.addTab(self.FrequencyAnalysis, "")
        self.ModalAnalysis = QtWidgets.QWidget()
        self.ModalAnalysis.setObjectName("ModalAnalysis")
        self.label_6 = QtWidgets.QLabel(self.ModalAnalysis)
        self.label_6.setGeometry(QtCore.QRect(13, 13, 471, 22))
        font = QtGui.QFont()
        font.setPointSize(9)
        self.label_6.setFont(font)
        self.label_6.setObjectName("label_6")
        self.Main_tabs.addTab(self.ModalAnalysis, "")
        self.gridLayout_3.addWidget(self.Main_tabs, 0, 0, 1, 1)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 956, 31))
        self.menubar.setObjectName("menubar")
        self.menuFile = QtWidgets.QMenu(self.menubar)
        self.menuFile.setObjectName("menuFile")
        MainWindow.setMenuBar(self.menubar)
        self.statusBar = QtWidgets.QStatusBar(MainWindow)
        self.statusBar.setObjectName("statusBar")
        MainWindow.setStatusBar(self.statusBar)
        self.actionload_files = QtWidgets.QAction(MainWindow)
        self.actionload_files.setObjectName("actionload_files")
        self.actionexit = QtWidgets.QAction(MainWindow)
        self.actionexit.setObjectName("actionexit")
        self.menuFile.addAction(self.actionload_files)
        self.menuFile.addAction(self.actionexit)
        self.menubar.addAction(self.menuFile.menuAction())

        self.retranslateUi(MainWindow)
        self.Main_tabs.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        MainWindow.setWindowTitle(QtWidgets.QApplication.translate("MainWindow", "PIV - Build 101", None, -1))
        self.settings_GB.setTitle(QtWidgets.QApplication.translate("MainWindow", "Thresholding Settings", None, -1))
        self.global_velocity_CB.setText(QtWidgets.QApplication.translate("MainWindow", "Global Velocity", None, -1))
        self.global_uVelocity_LE.setPlaceholderText(QtWidgets.QApplication.translate("MainWindow", "Umin, Umax", None, -1))
        self.global_vVelocity_LE.setPlaceholderText(QtWidgets.QApplication.translate("MainWindow", "Vmin, Vmax", None, -1))
        self.local_velocity_CB.setText(QtWidgets.QApplication.translate("MainWindow", "Local Median", None, -1))
        self.local_velocity_LE.setPlaceholderText(QtWidgets.QApplication.translate("MainWindow", "Udiff, Vdiff", None, -1))
        self.local_kernel_LE.setPlaceholderText(QtWidgets.QApplication.translate("MainWindow", "kernel size", None, -1))
        self.s2n_CB.setText(QtWidgets.QApplication.translate("MainWindow", "Signal 2 Noise", None, -1))
        self.global_std_CB.setText(QtWidgets.QApplication.translate("MainWindow", "Global Std. Deviation", None, -1))
        self.s2n_LE.setWhatsThis(QtWidgets.QApplication.translate("MainWindow", "<html><head/><body><p><br/></p></body></html>", None, -1))
        self.s2n_LE.setPlaceholderText(QtWidgets.QApplication.translate("MainWindow", "signal/noise", None, -1))
        self.global_std_LE.setPlaceholderText(QtWidgets.QApplication.translate("MainWindow", "std multiplier", None, -1))
        self.apply_settings_PB.setText(QtWidgets.QApplication.translate("MainWindow", "Apply Settings", None, -1))
        self.load_settings_PB.setText(QtWidgets.QApplication.translate("MainWindow", "Load Settings", None, -1))
        self.save_settings_PB.setText(QtWidgets.QApplication.translate("MainWindow", "Save Settings", None, -1))
        self.files_TW.setSortingEnabled(True)
        self.files_TW.headerItem().setText(0, QtWidgets.QApplication.translate("MainWindow", "File", None, -1))
        self.files_TW.headerItem().setText(1, QtWidgets.QApplication.translate("MainWindow", "Num. Bad Vector", None, -1))
        self.Main_tabs.setTabText(self.Main_tabs.indexOf(self.Validation), QtWidgets.QApplication.translate("MainWindow", "Validation", None, -1))
        self.label_4.setText(QtWidgets.QApplication.translate("MainWindow", "This part of the program is still under development.", None, -1))
        self.Main_tabs.setTabText(self.Main_tabs.indexOf(self.Process), QtWidgets.QApplication.translate("MainWindow", "Process", None, -1))
        self.label_5.setText(QtWidgets.QApplication.translate("MainWindow", "This part of the program is still under development.", None, -1))
        self.Main_tabs.setTabText(self.Main_tabs.indexOf(self.FrequencyAnalysis), QtWidgets.QApplication.translate("MainWindow", "Freq. Analysis", None, -1))
        self.label_6.setText(QtWidgets.QApplication.translate("MainWindow", "This part of the program is still under development.", None, -1))
        self.Main_tabs.setTabText(self.Main_tabs.indexOf(self.ModalAnalysis), QtWidgets.QApplication.translate("MainWindow", "Modal Analysis", None, -1))
        self.menuFile.setTitle(QtWidgets.QApplication.translate("MainWindow", "File", None, -1))
        self.actionload_files.setText(QtWidgets.QApplication.translate("MainWindow", "Load Files", None, -1))
        self.actionexit.setText(QtWidgets.QApplication.translate("MainWindow", "Exit", None, -1))





# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'main_piv.ui',
# licensing of 'main_piv.ui' applies.
#
# Created: Tue Nov 10 11:22:38 2020
#      by: pyside2-uic  running on PySide2 5.13.2
#
# WARNING! All changes made in this file will be lost!

from PySide2 import QtCore, QtGui, QtWidgets

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.setEnabled(True)
        MainWindow.resize(876, 720)
        MainWindow.setStyleSheet("")
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.gridLayout_11 = QtWidgets.QGridLayout(self.centralwidget)
        self.gridLayout_11.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_11.setObjectName("gridLayout_11")
        self.Main_tabs = QtWidgets.QTabWidget(self.centralwidget)
        self.Main_tabs.setEnabled(True)
        font = QtGui.QFont()
        font.setPointSize(8)
        font.setWeight(50)
        font.setItalic(False)
        font.setUnderline(False)
        font.setStrikeOut(False)
        font.setBold(False)
        self.Main_tabs.setFont(font)
        self.Main_tabs.setAcceptDrops(False)
        self.Main_tabs.setAccessibleDescription("")
        self.Main_tabs.setAutoFillBackground(False)
        self.Main_tabs.setStyleSheet("")
        self.Main_tabs.setTabPosition(QtWidgets.QTabWidget.North)
        self.Main_tabs.setTabShape(QtWidgets.QTabWidget.Rounded)
        self.Main_tabs.setElideMode(QtCore.Qt.ElideNone)
        self.Main_tabs.setUsesScrollButtons(True)
        self.Main_tabs.setDocumentMode(False)
        self.Main_tabs.setTabsClosable(False)
        self.Main_tabs.setMovable(False)
        self.Main_tabs.setTabBarAutoHide(False)
        self.Main_tabs.setObjectName("Main_tabs")
        self.Validation = QtWidgets.QWidget()
        self.Validation.setEnabled(True)
        self.Validation.setObjectName("Validation")
        self.gridLayout_4 = QtWidgets.QGridLayout(self.Validation)
        self.gridLayout_4.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.splitter = QtWidgets.QSplitter(self.Validation)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.splitter.sizePolicy().hasHeightForWidth())
        self.splitter.setSizePolicy(sizePolicy)
        self.splitter.setOrientation(QtCore.Qt.Horizontal)
        self.splitter.setObjectName("splitter")
        self.layoutWidget = QtWidgets.QWidget(self.splitter)
        self.layoutWidget.setObjectName("layoutWidget")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.layoutWidget)
        self.verticalLayout.setSpacing(5)
        self.verticalLayout.setContentsMargins(5, 10, 5, 5)
        self.verticalLayout.setObjectName("verticalLayout")
        self.settings_GB = QtWidgets.QGroupBox(self.layoutWidget)
        self.settings_GB.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.settings_GB.sizePolicy().hasHeightForWidth())
        self.settings_GB.setSizePolicy(sizePolicy)
        self.settings_GB.setMinimumSize(QtCore.QSize(0, 0))
        font = QtGui.QFont()
        font.setPointSize(8)
        font.setWeight(50)
        font.setItalic(False)
        font.setBold(False)
        self.settings_GB.setFont(font)
        self.settings_GB.setAutoFillBackground(False)
        self.settings_GB.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.settings_GB.setFlat(False)
        self.settings_GB.setCheckable(False)
        self.settings_GB.setChecked(False)
        self.settings_GB.setObjectName("settings_GB")
        self.gridLayout_5 = QtWidgets.QGridLayout(self.settings_GB)
        self.gridLayout_5.setSpacing(9)
        self.gridLayout_5.setContentsMargins(10, 10, 10, 10)
        self.gridLayout_5.setObjectName("gridLayout_5")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setSpacing(8)
        self.verticalLayout_2.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.gridLayout = QtWidgets.QGridLayout()
        self.gridLayout.setHorizontalSpacing(9)
        self.gridLayout.setObjectName("gridLayout")
        self.global_velocity_CB = QtWidgets.QCheckBox(self.settings_GB)
        self.global_velocity_CB.setEnabled(True)
        self.global_velocity_CB.setObjectName("global_velocity_CB")
        self.gridLayout.addWidget(self.global_velocity_CB, 1, 0, 1, 1)
        self.global_uVelocity_LE = QtWidgets.QLineEdit(self.settings_GB)
        self.global_uVelocity_LE.setObjectName("global_uVelocity_LE")
        self.gridLayout.addWidget(self.global_uVelocity_LE, 1, 1, 1, 1)
        self.global_vVelocity_LE = QtWidgets.QLineEdit(self.settings_GB)
        self.global_vVelocity_LE.setObjectName("global_vVelocity_LE")
        self.gridLayout.addWidget(self.global_vVelocity_LE, 1, 2, 1, 1)
        self.local_velocity_CB = QtWidgets.QCheckBox(self.settings_GB)
        self.local_velocity_CB.setEnabled(True)
        self.local_velocity_CB.setObjectName("local_velocity_CB")
        self.gridLayout.addWidget(self.local_velocity_CB, 2, 0, 1, 1)
        self.local_velocity_LE = QtWidgets.QLineEdit(self.settings_GB)
        self.local_velocity_LE.setObjectName("local_velocity_LE")
        self.gridLayout.addWidget(self.local_velocity_LE, 2, 1, 1, 1)
        self.local_kernel_LE = QtWidgets.QLineEdit(self.settings_GB)
        self.local_kernel_LE.setObjectName("local_kernel_LE")
        self.gridLayout.addWidget(self.local_kernel_LE, 2, 2, 1, 1)
        self.s2n_CB = QtWidgets.QCheckBox(self.settings_GB)
        self.s2n_CB.setEnabled(True)
        self.s2n_CB.setObjectName("s2n_CB")
        self.gridLayout.addWidget(self.s2n_CB, 0, 0, 1, 1)
        self.global_std_CB = QtWidgets.QCheckBox(self.settings_GB)
        self.global_std_CB.setEnabled(True)
        self.global_std_CB.setObjectName("global_std_CB")
        self.gridLayout.addWidget(self.global_std_CB, 3, 0, 1, 2)
        self.s2n_LE = QtWidgets.QLineEdit(self.settings_GB)
        self.s2n_LE.setEnabled(True)
        self.s2n_LE.setText("")
        self.s2n_LE.setFrame(True)
        self.s2n_LE.setObjectName("s2n_LE")
        self.gridLayout.addWidget(self.s2n_LE, 0, 2, 1, 1)
        self.global_std_LE = QtWidgets.QLineEdit(self.settings_GB)
        self.global_std_LE.setObjectName("global_std_LE")
        self.gridLayout.addWidget(self.global_std_LE, 3, 2, 1, 1)
        self.verticalLayout_2.addLayout(self.gridLayout)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setSpacing(12)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.apply_settings_PB = QtWidgets.QPushButton(self.settings_GB)
        self.apply_settings_PB.setObjectName("apply_settings_PB")
        self.horizontalLayout.addWidget(self.apply_settings_PB)
        self.load_settings_PB = QtWidgets.QPushButton(self.settings_GB)
        self.load_settings_PB.setObjectName("load_settings_PB")
        self.horizontalLayout.addWidget(self.load_settings_PB)
        self.save_settings_PB = QtWidgets.QPushButton(self.settings_GB)
        self.save_settings_PB.setEnabled(True)
        self.save_settings_PB.setObjectName("save_settings_PB")
        self.horizontalLayout.addWidget(self.save_settings_PB)
        self.verticalLayout_2.addLayout(self.horizontalLayout)
        self.gridLayout_5.addLayout(self.verticalLayout_2, 0, 0, 1, 1)
        self.verticalLayout.addWidget(self.settings_GB)
        self.files_TW = QtWidgets.QTreeWidget(self.layoutWidget)
        self.files_TW.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.files_TW.sizePolicy().hasHeightForWidth())
        self.files_TW.setSizePolicy(sizePolicy)
        self.files_TW.setMinimumSize(QtCore.QSize(0, 0))
        self.files_TW.setAutoScroll(True)
        self.files_TW.setIndentation(0)
        self.files_TW.setItemsExpandable(True)
        self.files_TW.setAnimated(True)
        self.files_TW.setAllColumnsShowFocus(False)
        self.files_TW.setWordWrap(False)
        self.files_TW.setHeaderHidden(False)
        self.files_TW.setObjectName("files_TW")
        self.files_TW.header().setSortIndicatorShown(True)
        self.verticalLayout.addWidget(self.files_TW)
        self.plot_widget = QtWidgets.QWidget(self.splitter)
        self.plot_widget.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.plot_widget.sizePolicy().hasHeightForWidth())
        self.plot_widget.setSizePolicy(sizePolicy)
        self.plot_widget.setMinimumSize(QtCore.QSize(450, 0))
        self.plot_widget.setAutoFillBackground(False)
        self.plot_widget.setObjectName("plot_widget")
        self.plot_settings_LE = QtWidgets.QLineEdit(self.plot_widget)
        self.plot_settings_LE.setGeometry(QtCore.QRect(160, 30, 70, 30))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.plot_settings_LE.sizePolicy().hasHeightForWidth())
        self.plot_settings_LE.setSizePolicy(sizePolicy)
        self.plot_settings_LE.setMinimumSize(QtCore.QSize(70, 0))
        self.plot_settings_LE.setMaximumSize(QtCore.QSize(70, 16777215))
        self.plot_settings_LE.setObjectName("plot_settings_LE")
        self.BV_settings_CB = QtWidgets.QComboBox(self.plot_widget)
        self.BV_settings_CB.setGeometry(QtCore.QRect(240, 30, 165, 30))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.BV_settings_CB.sizePolicy().hasHeightForWidth())
        self.BV_settings_CB.setSizePolicy(sizePolicy)
        self.BV_settings_CB.setMinimumSize(QtCore.QSize(165, 30))
        self.BV_settings_CB.setMaximumSize(QtCore.QSize(165, 16777215))
        self.BV_settings_CB.setObjectName("BV_settings_CB")
        self.BV_settings_CB.addItem("")
        self.BV_settings_CB.addItem("")
        self.BV_settings_CB.addItem("")
        self.BV_settings_CB.addItem("")
        self.gridLayout_4.addWidget(self.splitter, 0, 0, 1, 1)
        self.Main_tabs.addTab(self.Validation, "")
        self.Process = QtWidgets.QWidget()
        self.Process.setObjectName("Process")
        self.gridLayout_12 = QtWidgets.QGridLayout(self.Process)
        self.gridLayout_12.setContentsMargins(5, 10, 5, 0)
        self.gridLayout_12.setVerticalSpacing(9)
        self.gridLayout_12.setObjectName("gridLayout_12")
        self.groupBox_11 = QtWidgets.QGroupBox(self.Process)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_11.sizePolicy().hasHeightForWidth())
        self.groupBox_11.setSizePolicy(sizePolicy)
        self.groupBox_11.setObjectName("groupBox_11")
        self.gridLayout_25 = QtWidgets.QGridLayout(self.groupBox_11)
        self.gridLayout_25.setContentsMargins(10, 10, 10, 15)
        self.gridLayout_25.setObjectName("gridLayout_25")
        self.gridLayout_26 = QtWidgets.QGridLayout()
        self.gridLayout_26.setHorizontalSpacing(15)
        self.gridLayout_26.setVerticalSpacing(12)
        self.gridLayout_26.setObjectName("gridLayout_26")
        self.label_21 = QtWidgets.QLabel(self.groupBox_11)
        self.label_21.setObjectName("label_21")
        self.gridLayout_26.addWidget(self.label_21, 0, 0, 1, 1)
        self.label_22 = QtWidgets.QLabel(self.groupBox_11)
        self.label_22.setObjectName("label_22")
        self.gridLayout_26.addWidget(self.label_22, 1, 0, 1, 1)
        self.run_start_PB = QtWidgets.QPushButton(self.groupBox_11)
        self.run_start_PB.setEnabled(True)
        self.run_start_PB.setStyleSheet("")
        self.run_start_PB.setObjectName("run_start_PB")
        self.gridLayout_26.addWidget(self.run_start_PB, 0, 2, 1, 1)
        self.run_stop_PB = QtWidgets.QPushButton(self.groupBox_11)
        self.run_stop_PB.setEnabled(True)
        self.run_stop_PB.setObjectName("run_stop_PB")
        self.gridLayout_26.addWidget(self.run_stop_PB, 0, 3, 1, 1)
        self.run_overalprogress_PBar = QtWidgets.QProgressBar(self.groupBox_11)
        self.run_overalprogress_PBar.setEnabled(False)
        self.run_overalprogress_PBar.setStyleSheet("")
        self.run_overalprogress_PBar.setProperty("value", 0)
        self.run_overalprogress_PBar.setTextVisible(True)
        self.run_overalprogress_PBar.setObjectName("run_overalprogress_PBar")
        self.gridLayout_26.addWidget(self.run_overalprogress_PBar, 2, 1, 1, 3)
        self.run_progress_PBar = QtWidgets.QProgressBar(self.groupBox_11)
        self.run_progress_PBar.setEnabled(False)
        self.run_progress_PBar.setStyleSheet("")
        self.run_progress_PBar.setProperty("value", 0)
        self.run_progress_PBar.setObjectName("run_progress_PBar")
        self.gridLayout_26.addWidget(self.run_progress_PBar, 1, 1, 1, 3)
        self.label_23 = QtWidgets.QLabel(self.groupBox_11)
        self.label_23.setObjectName("label_23")
        self.gridLayout_26.addWidget(self.label_23, 2, 0, 1, 1)
        self.run_progress_TE = QtWidgets.QPlainTextEdit(self.groupBox_11)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.run_progress_TE.sizePolicy().hasHeightForWidth())
        self.run_progress_TE.setSizePolicy(sizePolicy)
        self.run_progress_TE.setMaximumSize(QtCore.QSize(16777215, 80))
        self.run_progress_TE.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.run_progress_TE.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.run_progress_TE.setMidLineWidth(3)
        self.run_progress_TE.setHorizontalScrollBarPolicy(QtCore.Qt.ScrollBarAsNeeded)
        self.run_progress_TE.setTabChangesFocus(True)
        self.run_progress_TE.setUndoRedoEnabled(False)
        self.run_progress_TE.setReadOnly(True)
        self.run_progress_TE.setTextInteractionFlags(QtCore.Qt.TextSelectableByKeyboard|QtCore.Qt.TextSelectableByMouse)
        self.run_progress_TE.setCenterOnScroll(True)
        self.run_progress_TE.setObjectName("run_progress_TE")
        self.gridLayout_26.addWidget(self.run_progress_TE, 0, 1, 1, 1)
        self.gridLayout_25.addLayout(self.gridLayout_26, 0, 0, 1, 1)
        self.gridLayout_12.addWidget(self.groupBox_11, 1, 0, 1, 1)
        self.groupBox_7 = QtWidgets.QGroupBox(self.Process)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_7.sizePolicy().hasHeightForWidth())
        self.groupBox_7.setSizePolicy(sizePolicy)
        self.groupBox_7.setObjectName("groupBox_7")
        self.gridLayout_18 = QtWidgets.QGridLayout(self.groupBox_7)
        self.gridLayout_18.setContentsMargins(10, 10, 10, 10)
        self.gridLayout_18.setHorizontalSpacing(6)
        self.gridLayout_18.setObjectName("gridLayout_18")
        spacerItem = QtWidgets.QSpacerItem(398, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_18.addItem(spacerItem, 2, 0, 1, 1)
        self.process_loadsettings_PB = QtWidgets.QPushButton(self.groupBox_7)
        self.process_loadsettings_PB.setObjectName("process_loadsettings_PB")
        self.gridLayout_18.addWidget(self.process_loadsettings_PB, 2, 1, 1, 1)
        self.toolBox = QtWidgets.QToolBox(self.groupBox_7)
        self.toolBox.setEnabled(True)
        self.toolBox.setContextMenuPolicy(QtCore.Qt.DefaultContextMenu)
        self.toolBox.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.toolBox.setAutoFillBackground(False)
        self.toolBox.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.toolBox.setFrameShadow(QtWidgets.QFrame.Raised)
        self.toolBox.setObjectName("toolBox")
        self.ExpPage = QtWidgets.QWidget()
        self.ExpPage.setGeometry(QtCore.QRect(0, 0, 838, 302))
        self.ExpPage.setObjectName("ExpPage")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.ExpPage)
        self.gridLayout_2.setContentsMargins(8, 0, 8, 0)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.gridLayout_13 = QtWidgets.QGridLayout()
        self.gridLayout_13.setHorizontalSpacing(10)
        self.gridLayout_13.setVerticalSpacing(8)
        self.gridLayout_13.setObjectName("gridLayout_13")
        self.label_24 = QtWidgets.QLabel(self.ExpPage)
        self.label_24.setObjectName("label_24")
        self.gridLayout_13.addWidget(self.label_24, 0, 0, 1, 1)
        self.exp_directory_TB = QtWidgets.QToolButton(self.ExpPage)
        self.exp_directory_TB.setObjectName("exp_directory_TB")
        self.gridLayout_13.addWidget(self.exp_directory_TB, 0, 6, 1, 1)
        self.exp_experiments_LE = QtWidgets.QLineEdit(self.ExpPage)
        self.exp_experiments_LE.setText("")
        self.exp_experiments_LE.setObjectName("exp_experiments_LE")
        self.gridLayout_13.addWidget(self.exp_experiments_LE, 1, 1, 1, 6)
        self.label_14 = QtWidgets.QLabel(self.ExpPage)
        self.label_14.setObjectName("label_14")
        self.gridLayout_13.addWidget(self.label_14, 2, 0, 1, 1)
        self.exp_runs_LE = QtWidgets.QLineEdit(self.ExpPage)
        self.exp_runs_LE.setText("")
        self.exp_runs_LE.setObjectName("exp_runs_LE")
        self.gridLayout_13.addWidget(self.exp_runs_LE, 2, 1, 1, 6)
        self.label_25 = QtWidgets.QLabel(self.ExpPage)
        self.label_25.setObjectName("label_25")
        self.gridLayout_13.addWidget(self.label_25, 1, 0, 1, 1)
        self.exp_directory_LE = QtWidgets.QLineEdit(self.ExpPage)
        self.exp_directory_LE.setText("")
        self.exp_directory_LE.setObjectName("exp_directory_LE")
        self.gridLayout_13.addWidget(self.exp_directory_LE, 0, 1, 1, 5)
        self.label = QtWidgets.QLabel(self.ExpPage)
        self.label.setObjectName("label")
        self.gridLayout_13.addWidget(self.label, 3, 0, 1, 1)
        self.exp_patA_LE = QtWidgets.QLineEdit(self.ExpPage)
        self.exp_patA_LE.setObjectName("exp_patA_LE")
        self.gridLayout_13.addWidget(self.exp_patA_LE, 3, 1, 1, 1)
        self.label_2 = QtWidgets.QLabel(self.ExpPage)
        self.label_2.setObjectName("label_2")
        self.gridLayout_13.addWidget(self.label_2, 3, 2, 1, 1)
        self.label_3 = QtWidgets.QLabel(self.ExpPage)
        self.label_3.setObjectName("label_3")
        self.gridLayout_13.addWidget(self.label_3, 3, 4, 1, 1)
        self.exp_patB_LE = QtWidgets.QLineEdit(self.ExpPage)
        self.exp_patB_LE.setObjectName("exp_patB_LE")
        self.gridLayout_13.addWidget(self.exp_patB_LE, 3, 3, 1, 1)
        self.exp_nfiles_LE = QtWidgets.QLineEdit(self.ExpPage)
        self.exp_nfiles_LE.setObjectName("exp_nfiles_LE")
        self.gridLayout_13.addWidget(self.exp_nfiles_LE, 3, 5, 1, 2)
        self.gridLayout_2.addLayout(self.gridLayout_13, 0, 0, 1, 1)
        self.toolBox.addItem(self.ExpPage, "")
        self.PrePage = QtWidgets.QWidget()
        self.PrePage.setGeometry(QtCore.QRect(0, 0, 815, 302))
        self.PrePage.setObjectName("PrePage")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.PrePage)
        self.gridLayout_3.setContentsMargins(8, 0, 8, 0)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.gridLayout_7 = QtWidgets.QGridLayout()
        self.gridLayout_7.setHorizontalSpacing(10)
        self.gridLayout_7.setVerticalSpacing(8)
        self.gridLayout_7.setObjectName("gridLayout_7")
        self.pre_bg_ncpus_LE = QtWidgets.QLineEdit(self.PrePage)
        self.pre_bg_ncpus_LE.setObjectName("pre_bg_ncpus_LE")
        self.gridLayout_7.addWidget(self.pre_bg_ncpus_LE, 0, 3, 1, 2)
        self.pre_staticmask_CB = QtWidgets.QCheckBox(self.PrePage)
        self.pre_staticmask_CB.setObjectName("pre_staticmask_CB")
        self.gridLayout_7.addWidget(self.pre_staticmask_CB, 1, 0, 1, 1)
        self.pre_sm_path_LE = QtWidgets.QLineEdit(self.PrePage)
        self.pre_sm_path_LE.setObjectName("pre_sm_path_LE")
        self.gridLayout_7.addWidget(self.pre_sm_path_LE, 1, 1, 1, 3)
        self.pre_bg_nfiles_LE = QtWidgets.QLineEdit(self.PrePage)
        self.pre_bg_nfiles_LE.setObjectName("pre_bg_nfiles_LE")
        self.gridLayout_7.addWidget(self.pre_bg_nfiles_LE, 0, 1, 1, 1)
        self.pre_background_CB = QtWidgets.QCheckBox(self.PrePage)
        self.pre_background_CB.setObjectName("pre_background_CB")
        self.gridLayout_7.addWidget(self.pre_background_CB, 0, 0, 1, 1)
        self.pre_bg_chunksize_LE = QtWidgets.QLineEdit(self.PrePage)
        self.pre_bg_chunksize_LE.setObjectName("pre_bg_chunksize_LE")
        self.gridLayout_7.addWidget(self.pre_bg_chunksize_LE, 0, 2, 1, 1)
        self.pre_dynamicmask_CB = QtWidgets.QCheckBox(self.PrePage)
        self.pre_dynamicmask_CB.setObjectName("pre_dynamicmask_CB")
        self.gridLayout_7.addWidget(self.pre_dynamicmask_CB, 2, 0, 1, 3)
        self.pre_sm_path_TB = QtWidgets.QToolButton(self.PrePage)
        self.pre_sm_path_TB.setObjectName("pre_sm_path_TB")
        self.gridLayout_7.addWidget(self.pre_sm_path_TB, 1, 4, 1, 1)
        self.gridLayout_3.addLayout(self.gridLayout_7, 0, 0, 1, 1)
        self.toolBox.addItem(self.PrePage, "")
        self.ProPage = QtWidgets.QWidget()
        self.ProPage.setGeometry(QtCore.QRect(0, 0, 838, 302))
        self.ProPage.setObjectName("ProPage")
        self.gridLayout_8 = QtWidgets.QGridLayout(self.ProPage)
        self.gridLayout_8.setContentsMargins(8, 0, 8, 0)
        self.gridLayout_8.setObjectName("gridLayout_8")
        self.gridLayout_9 = QtWidgets.QGridLayout()
        self.gridLayout_9.setHorizontalSpacing(10)
        self.gridLayout_9.setVerticalSpacing(8)
        self.gridLayout_9.setObjectName("gridLayout_9")
        self.pro_scale_LE = QtWidgets.QLineEdit(self.ProPage)
        self.pro_scale_LE.setText("")
        self.pro_scale_LE.setPlaceholderText("")
        self.pro_scale_LE.setObjectName("pro_scale_LE")
        self.gridLayout_9.addWidget(self.pro_scale_LE, 1, 6, 1, 1)
        self.pro_searcharea_LE = QtWidgets.QLineEdit(self.ProPage)
        self.pro_searcharea_LE.setText("")
        self.pro_searcharea_LE.setPlaceholderText("")
        self.pro_searcharea_LE.setObjectName("pro_searcharea_LE")
        self.gridLayout_9.addWidget(self.pro_searcharea_LE, 0, 4, 1, 1)
        self.label_8 = QtWidgets.QLabel(self.ProPage)
        self.label_8.setObjectName("label_8")
        self.gridLayout_9.addWidget(self.label_8, 2, 0, 1, 2)
        self.label_7 = QtWidgets.QLabel(self.ProPage)
        self.label_7.setObjectName("label_7")
        self.gridLayout_9.addWidget(self.label_7, 0, 5, 1, 1)
        self.label_10 = QtWidgets.QLabel(self.ProPage)
        self.label_10.setObjectName("label_10")
        self.gridLayout_9.addWidget(self.label_10, 1, 3, 1, 1)
        self.label_12 = QtWidgets.QLabel(self.ProPage)
        self.label_12.setObjectName("label_12")
        self.gridLayout_9.addWidget(self.label_12, 1, 5, 1, 1)
        self.label_11 = QtWidgets.QLabel(self.ProPage)
        self.label_11.setObjectName("label_11")
        self.gridLayout_9.addWidget(self.label_11, 1, 0, 1, 2)
        self.pro_sig2noise_CB = QtWidgets.QComboBox(self.ProPage)
        self.pro_sig2noise_CB.setObjectName("pro_sig2noise_CB")
        self.pro_sig2noise_CB.addItem("")
        self.pro_sig2noise_CB.addItem("")
        self.pro_sig2noise_CB.addItem("")
        self.gridLayout_9.addWidget(self.pro_sig2noise_CB, 1, 2, 1, 1)
        self.pro_timestep_LE = QtWidgets.QLineEdit(self.ProPage)
        self.pro_timestep_LE.setText("")
        self.pro_timestep_LE.setPlaceholderText("")
        self.pro_timestep_LE.setObjectName("pro_timestep_LE")
        self.gridLayout_9.addWidget(self.pro_timestep_LE, 1, 4, 1, 1)
        self.pro_ncpus_LE = QtWidgets.QLineEdit(self.ProPage)
        self.pro_ncpus_LE.setText("")
        self.pro_ncpus_LE.setPlaceholderText("")
        self.pro_ncpus_LE.setObjectName("pro_ncpus_LE")
        self.gridLayout_9.addWidget(self.pro_ncpus_LE, 2, 2, 1, 1)
        self.pro_overlap_LE = QtWidgets.QLineEdit(self.ProPage)
        self.pro_overlap_LE.setText("")
        self.pro_overlap_LE.setPlaceholderText("")
        self.pro_overlap_LE.setObjectName("pro_overlap_LE")
        self.gridLayout_9.addWidget(self.pro_overlap_LE, 0, 6, 1, 1)
        self.label_4 = QtWidgets.QLabel(self.ProPage)
        self.label_4.setObjectName("label_4")
        self.gridLayout_9.addWidget(self.label_4, 0, 3, 1, 1)
        self.label_9 = QtWidgets.QLabel(self.ProPage)
        self.label_9.setObjectName("label_9")
        self.gridLayout_9.addWidget(self.label_9, 0, 0, 1, 2)
        self.pro_windowsize_LE = QtWidgets.QLineEdit(self.ProPage)
        self.pro_windowsize_LE.setText("")
        self.pro_windowsize_LE.setPlaceholderText("")
        self.pro_windowsize_LE.setObjectName("pro_windowsize_LE")
        self.gridLayout_9.addWidget(self.pro_windowsize_LE, 0, 2, 1, 1)
        self.gridLayout_8.addLayout(self.gridLayout_9, 0, 0, 1, 1)
        self.toolBox.addItem(self.ProPage, "")
        self.PosPage = QtWidgets.QWidget()
        self.PosPage.setGeometry(QtCore.QRect(0, 0, 838, 302))
        self.PosPage.setObjectName("PosPage")
        self.gridLayout_10 = QtWidgets.QGridLayout(self.PosPage)
        self.gridLayout_10.setObjectName("gridLayout_10")
        self.groupBox_9 = QtWidgets.QGroupBox(self.PosPage)
        self.groupBox_9.setObjectName("groupBox_9")
        self.gridLayout_21 = QtWidgets.QGridLayout(self.groupBox_9)
        self.gridLayout_21.setContentsMargins(8, 10, 8, 5)
        self.gridLayout_21.setObjectName("gridLayout_21")
        self.gridLayout_22 = QtWidgets.QGridLayout()
        self.gridLayout_22.setObjectName("gridLayout_22")
        self.pos_std_LE = QtWidgets.QLineEdit(self.groupBox_9)
        self.pos_std_LE.setObjectName("pos_std_LE")
        self.gridLayout_22.addWidget(self.pos_std_LE, 1, 1, 1, 1)
        self.pos_s2n_ratio_LE = QtWidgets.QLineEdit(self.groupBox_9)
        self.pos_s2n_ratio_LE.setEnabled(True)
        self.pos_s2n_ratio_LE.setText("")
        self.pos_s2n_ratio_LE.setFrame(True)
        self.pos_s2n_ratio_LE.setObjectName("pos_s2n_ratio_LE")
        self.gridLayout_22.addWidget(self.pos_s2n_ratio_LE, 0, 1, 1, 1)
        self.pos_gv_ulim_LE = QtWidgets.QLineEdit(self.groupBox_9)
        self.pos_gv_ulim_LE.setObjectName("pos_gv_ulim_LE")
        self.gridLayout_22.addWidget(self.pos_gv_ulim_LE, 0, 3, 1, 1)
        self.pos_std_CB = QtWidgets.QCheckBox(self.groupBox_9)
        self.pos_std_CB.setEnabled(True)
        self.pos_std_CB.setObjectName("pos_std_CB")
        self.gridLayout_22.addWidget(self.pos_std_CB, 1, 0, 1, 1)
        self.pos_localvelocity_CB = QtWidgets.QCheckBox(self.groupBox_9)
        self.pos_localvelocity_CB.setEnabled(True)
        self.pos_localvelocity_CB.setObjectName("pos_localvelocity_CB")
        self.gridLayout_22.addWidget(self.pos_localvelocity_CB, 1, 2, 1, 1)
        self.pos_lv_uvdiff_LE = QtWidgets.QLineEdit(self.groupBox_9)
        self.pos_lv_uvdiff_LE.setObjectName("pos_lv_uvdiff_LE")
        self.gridLayout_22.addWidget(self.pos_lv_uvdiff_LE, 1, 3, 1, 1)
        self.pos_sig2noise_CB = QtWidgets.QCheckBox(self.groupBox_9)
        self.pos_sig2noise_CB.setEnabled(True)
        self.pos_sig2noise_CB.setObjectName("pos_sig2noise_CB")
        self.gridLayout_22.addWidget(self.pos_sig2noise_CB, 0, 0, 1, 1)
        self.pos_globalvelocity_CB = QtWidgets.QCheckBox(self.groupBox_9)
        self.pos_globalvelocity_CB.setEnabled(True)
        self.pos_globalvelocity_CB.setObjectName("pos_globalvelocity_CB")
        self.gridLayout_22.addWidget(self.pos_globalvelocity_CB, 0, 2, 1, 1)
        self.pos_lv_kernel_LE = QtWidgets.QLineEdit(self.groupBox_9)
        self.pos_lv_kernel_LE.setObjectName("pos_lv_kernel_LE")
        self.gridLayout_22.addWidget(self.pos_lv_kernel_LE, 1, 4, 1, 1)
        self.pos_gv_vlim_LE = QtWidgets.QLineEdit(self.groupBox_9)
        self.pos_gv_vlim_LE.setObjectName("pos_gv_vlim_LE")
        self.gridLayout_22.addWidget(self.pos_gv_vlim_LE, 0, 4, 1, 1)
        self.gridLayout_21.addLayout(self.gridLayout_22, 0, 0, 1, 1)
        self.gridLayout_10.addWidget(self.groupBox_9, 0, 0, 1, 1)
        self.groupBox_10 = QtWidgets.QGroupBox(self.PosPage)
        self.groupBox_10.setObjectName("groupBox_10")
        self.gridLayout_14 = QtWidgets.QGridLayout(self.groupBox_10)
        self.gridLayout_14.setContentsMargins(9, -1, -1, -1)
        self.gridLayout_14.setObjectName("gridLayout_14")
        self.gridLayout_6 = QtWidgets.QGridLayout()
        self.gridLayout_6.setObjectName("gridLayout_6")
        self.pos_badvector_CB = QtWidgets.QCheckBox(self.groupBox_10)
        self.pos_badvector_CB.setEnabled(True)
        self.pos_badvector_CB.setObjectName("pos_badvector_CB")
        self.gridLayout_6.addWidget(self.pos_badvector_CB, 0, 0, 1, 2)
        self.pos_bv_niterations_LE = QtWidgets.QLineEdit(self.groupBox_10)
        self.pos_bv_niterations_LE.setObjectName("pos_bv_niterations_LE")
        self.gridLayout_6.addWidget(self.pos_bv_niterations_LE, 0, 3, 1, 1)
        self.pos_bv_method_CB = QtWidgets.QComboBox(self.groupBox_10)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pos_bv_method_CB.sizePolicy().hasHeightForWidth())
        self.pos_bv_method_CB.setSizePolicy(sizePolicy)
        self.pos_bv_method_CB.setObjectName("pos_bv_method_CB")
        self.pos_bv_method_CB.addItem("")
        self.pos_bv_method_CB.addItem("")
        self.pos_bv_method_CB.addItem("")
        self.gridLayout_6.addWidget(self.pos_bv_method_CB, 0, 2, 1, 1)
        self.pos_bv_kernel_LE = QtWidgets.QLineEdit(self.groupBox_10)
        self.pos_bv_kernel_LE.setObjectName("pos_bv_kernel_LE")
        self.gridLayout_6.addWidget(self.pos_bv_kernel_LE, 0, 4, 1, 1)
        self.pos_smth_factor_LE = QtWidgets.QLineEdit(self.groupBox_10)
        self.pos_smth_factor_LE.setObjectName("pos_smth_factor_LE")
        self.gridLayout_6.addWidget(self.pos_smth_factor_LE, 1, 2, 1, 1)
        self.pos_smoothing_CB = QtWidgets.QCheckBox(self.groupBox_10)
        self.pos_smoothing_CB.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pos_smoothing_CB.sizePolicy().hasHeightForWidth())
        self.pos_smoothing_CB.setSizePolicy(sizePolicy)
        self.pos_smoothing_CB.setObjectName("pos_smoothing_CB")
        self.gridLayout_6.addWidget(self.pos_smoothing_CB, 1, 0, 1, 2)
        self.pos_fm_LE = QtWidgets.QLineEdit(self.groupBox_10)
        self.pos_fm_LE.setObjectName("pos_fm_LE")
        self.gridLayout_6.addWidget(self.pos_fm_LE, 2, 2, 1, 1)
        self.pos_fieldmanip_CB = QtWidgets.QCheckBox(self.groupBox_10)
        self.pos_fieldmanip_CB.setEnabled(True)
        self.pos_fieldmanip_CB.setObjectName("pos_fieldmanip_CB")
        self.gridLayout_6.addWidget(self.pos_fieldmanip_CB, 2, 0, 1, 2)
        self.gridLayout_14.addLayout(self.gridLayout_6, 0, 0, 1, 1)
        self.gridLayout_10.addWidget(self.groupBox_10, 1, 0, 1, 1)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setSpacing(6)
        self.horizontalLayout_3.setSizeConstraint(QtWidgets.QLayout.SetDefaultConstraint)
        self.horizontalLayout_3.setContentsMargins(5, 10, 25, -1)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.label_15 = QtWidgets.QLabel(self.PosPage)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_15.sizePolicy().hasHeightForWidth())
        self.label_15.setSizePolicy(sizePolicy)
        self.label_15.setMinimumSize(QtCore.QSize(150, 0))
        self.label_15.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_15.setObjectName("label_15")
        self.horizontalLayout_3.addWidget(self.label_15)
        self.pos_output_CB = QtWidgets.QComboBox(self.PosPage)
        self.pos_output_CB.setObjectName("pos_output_CB")
        self.pos_output_CB.addItem("")
        self.pos_output_CB.addItem("")
        self.horizontalLayout_3.addWidget(self.pos_output_CB)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem1)
        self.horizontalLayout_3.setStretch(1, 1)
        self.horizontalLayout_3.setStretch(2, 2)
        self.gridLayout_10.addLayout(self.horizontalLayout_3, 2, 0, 1, 1)
        self.toolBox.addItem(self.PosPage, "")
        self.gridLayout_18.addWidget(self.toolBox, 0, 0, 1, 3)
        self.process_savesettings_PB = QtWidgets.QPushButton(self.groupBox_7)
        self.process_savesettings_PB.setObjectName("process_savesettings_PB")
        self.gridLayout_18.addWidget(self.process_savesettings_PB, 2, 2, 1, 1)
        self.gridLayout_12.addWidget(self.groupBox_7, 0, 0, 1, 1)
        self.Main_tabs.addTab(self.Process, "")
        self.FrequencyAnalysis = QtWidgets.QWidget()
        self.FrequencyAnalysis.setObjectName("FrequencyAnalysis")
        self.label_13 = QtWidgets.QLabel(self.FrequencyAnalysis)
        self.label_13.setGeometry(QtCore.QRect(10, 20, 471, 22))
        font = QtGui.QFont()
        font.setPointSize(9)
        self.label_13.setFont(font)
        self.label_13.setObjectName("label_13")
        self.Main_tabs.addTab(self.FrequencyAnalysis, "")
        self.ModalAnalysis = QtWidgets.QWidget()
        self.ModalAnalysis.setObjectName("ModalAnalysis")
        self.label_6 = QtWidgets.QLabel(self.ModalAnalysis)
        self.label_6.setGeometry(QtCore.QRect(10, 20, 471, 22))
        font = QtGui.QFont()
        font.setPointSize(9)
        self.label_6.setFont(font)
        self.label_6.setObjectName("label_6")
        self.Main_tabs.addTab(self.ModalAnalysis, "")
        self.gridLayout_11.addWidget(self.Main_tabs, 0, 0, 1, 1)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 876, 21))
        self.menubar.setObjectName("menubar")
        self.menuFile = QtWidgets.QMenu(self.menubar)
        self.menuFile.setObjectName("menuFile")
        self.menuHelp = QtWidgets.QMenu(self.menubar)
        self.menuHelp.setObjectName("menuHelp")
        MainWindow.setMenuBar(self.menubar)
        self.actionLoad_Files = QtWidgets.QAction(MainWindow)
        self.actionLoad_Files.setObjectName("actionLoad_Files")
        self.actionExit = QtWidgets.QAction(MainWindow)
        self.actionExit.setObjectName("actionExit")
        self.actionClear_Files = QtWidgets.QAction(MainWindow)
        self.actionClear_Files.setObjectName("actionClear_Files")
        self.actionLoad_Raw_Images = QtWidgets.QAction(MainWindow)
        self.actionLoad_Raw_Images.setObjectName("actionLoad_Raw_Images")
        self.actionAbout = QtWidgets.QAction(MainWindow)
        self.actionAbout.setObjectName("actionAbout")
        self.menuFile.addAction(self.actionLoad_Files)
        self.menuFile.addAction(self.actionLoad_Raw_Images)
        self.menuFile.addAction(self.actionClear_Files)
        self.menuFile.addAction(self.actionExit)
        self.menuHelp.addAction(self.actionAbout)
        self.menubar.addAction(self.menuFile.menuAction())
        self.menubar.addAction(self.menuHelp.menuAction())

        self.retranslateUi(MainWindow)
        self.Main_tabs.setCurrentIndex(1)
        self.toolBox.setCurrentIndex(3)
        self.toolBox.layout().setSpacing(4)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        self.settings_GB.setTitle(QtWidgets.QApplication.translate("MainWindow", "Thresholding Settings", None, -1))
        self.global_velocity_CB.setText(QtWidgets.QApplication.translate("MainWindow", "Global Velocity", None, -1))
        self.global_uVelocity_LE.setPlaceholderText(QtWidgets.QApplication.translate("MainWindow", "Umin, Umax", None, -1))
        self.global_vVelocity_LE.setPlaceholderText(QtWidgets.QApplication.translate("MainWindow", "Vmin, Vmax", None, -1))
        self.local_velocity_CB.setText(QtWidgets.QApplication.translate("MainWindow", "Local Median", None, -1))
        self.local_velocity_LE.setPlaceholderText(QtWidgets.QApplication.translate("MainWindow", "Udiff, Vdiff", None, -1))
        self.local_kernel_LE.setPlaceholderText(QtWidgets.QApplication.translate("MainWindow", "kernel size", None, -1))
        self.s2n_CB.setText(QtWidgets.QApplication.translate("MainWindow", "Signal 2 Noise", None, -1))
        self.global_std_CB.setText(QtWidgets.QApplication.translate("MainWindow", "Global Std. Deviation", None, -1))
        self.s2n_LE.setWhatsThis(QtWidgets.QApplication.translate("MainWindow", "<html><head/><body><p><br/></p></body></html>", None, -1))
        self.s2n_LE.setPlaceholderText(QtWidgets.QApplication.translate("MainWindow", "signal/noise", None, -1))
        self.global_std_LE.setPlaceholderText(QtWidgets.QApplication.translate("MainWindow", "std multiplier", None, -1))
        self.apply_settings_PB.setText(QtWidgets.QApplication.translate("MainWindow", "Apply Settings", None, -1))
        self.load_settings_PB.setText(QtWidgets.QApplication.translate("MainWindow", "Load Settings", None, -1))
        self.save_settings_PB.setText(QtWidgets.QApplication.translate("MainWindow", "Save Settings", None, -1))
        self.files_TW.setSortingEnabled(True)
        self.files_TW.headerItem().setText(0, QtWidgets.QApplication.translate("MainWindow", "File", None, -1))
        self.files_TW.headerItem().setText(1, QtWidgets.QApplication.translate("MainWindow", "Num. Bad Vector", None, -1))
        self.plot_settings_LE.setText(QtWidgets.QApplication.translate("MainWindow", "b,r,50,2", None, -1))
        self.plot_settings_LE.setPlaceholderText(QtWidgets.QApplication.translate("MainWindow", "b,r,50,2", None, -1))
        self.BV_settings_CB.setItemText(0, QtWidgets.QApplication.translate("MainWindow", "Show Original BV", None, -1))
        self.BV_settings_CB.setItemText(1, QtWidgets.QApplication.translate("MainWindow", "Show Replaced BV", None, -1))
        self.BV_settings_CB.setItemText(2, QtWidgets.QApplication.translate("MainWindow", "Do Not Show BV", None, -1))
        self.BV_settings_CB.setItemText(3, QtWidgets.QApplication.translate("MainWindow", "Only Show BV", None, -1))
        self.Main_tabs.setTabText(self.Main_tabs.indexOf(self.Validation), QtWidgets.QApplication.translate("MainWindow", "Validation", None, -1))
        self.groupBox_11.setTitle(QtWidgets.QApplication.translate("MainWindow", "Run", None, -1))
        self.label_21.setText(QtWidgets.QApplication.translate("MainWindow", "Progress", None, -1))
        self.label_22.setText(QtWidgets.QApplication.translate("MainWindow", "Run Progress", None, -1))
        self.run_start_PB.setText(QtWidgets.QApplication.translate("MainWindow", "Start", None, -1))
        self.run_stop_PB.setText(QtWidgets.QApplication.translate("MainWindow", "Stop", None, -1))
        self.label_23.setText(QtWidgets.QApplication.translate("MainWindow", "Overal Progress", None, -1))
        self.run_progress_TE.setPlaceholderText(QtWidgets.QApplication.translate("MainWindow", "Details of the run are shown here...", None, -1))
        self.groupBox_7.setTitle(QtWidgets.QApplication.translate("MainWindow", "Run Settings", None, -1))
        self.process_loadsettings_PB.setText(QtWidgets.QApplication.translate("MainWindow", "Load Settings", None, -1))
        self.label_24.setText(QtWidgets.QApplication.translate("MainWindow", "Directory", None, -1))
        self.exp_directory_TB.setText(QtWidgets.QApplication.translate("MainWindow", "...", None, -1))
        self.exp_experiments_LE.setPlaceholderText(QtWidgets.QApplication.translate("MainWindow", "Experiments separated by a comma (,)", None, -1))
        self.label_14.setText(QtWidgets.QApplication.translate("MainWindow", "Runs", None, -1))
        self.exp_runs_LE.setPlaceholderText(QtWidgets.QApplication.translate("MainWindow", "Runs separated by a comma (,)", None, -1))
        self.label_25.setText(QtWidgets.QApplication.translate("MainWindow", "Experiments", None, -1))
        self.exp_directory_LE.setPlaceholderText(QtWidgets.QApplication.translate("MainWindow", "Path to the experiment directory", None, -1))
        self.label.setText(QtWidgets.QApplication.translate("MainWindow", "Pattern A", None, -1))
        self.exp_patA_LE.setPlaceholderText(QtWidgets.QApplication.translate("MainWindow", "Pattern for frame_a", None, -1))
        self.label_2.setText(QtWidgets.QApplication.translate("MainWindow", "Pattern B", None, -1))
        self.label_3.setText(QtWidgets.QApplication.translate("MainWindow", "Num. of files", None, -1))
        self.exp_patB_LE.setPlaceholderText(QtWidgets.QApplication.translate("MainWindow", "Pattern for frame_b", None, -1))
        self.exp_nfiles_LE.setPlaceholderText(QtWidgets.QApplication.translate("MainWindow", "Number of files in each run", None, -1))
        self.toolBox.setItemText(self.toolBox.indexOf(self.ExpPage), QtWidgets.QApplication.translate("MainWindow", "Experiment", None, -1))
        self.pre_bg_ncpus_LE.setPlaceholderText(QtWidgets.QApplication.translate("MainWindow", "Number of CPUs", None, -1))
        self.pre_staticmask_CB.setText(QtWidgets.QApplication.translate("MainWindow", "Static Mask", None, -1))
        self.pre_sm_path_LE.setPlaceholderText(QtWidgets.QApplication.translate("MainWindow", "Path to the mask image", None, -1))
        self.pre_bg_nfiles_LE.setPlaceholderText(QtWidgets.QApplication.translate("MainWindow", "Number of files to consider", None, -1))
        self.pre_background_CB.setText(QtWidgets.QApplication.translate("MainWindow", "Remove Background", None, -1))
        self.pre_bg_chunksize_LE.setPlaceholderText(QtWidgets.QApplication.translate("MainWindow", "Chunk size", None, -1))
        self.pre_dynamicmask_CB.setText(QtWidgets.QApplication.translate("MainWindow", "Dynamic Mask (still under development)", None, -1))
        self.pre_sm_path_TB.setText(QtWidgets.QApplication.translate("MainWindow", "...", None, -1))
        self.toolBox.setItemText(self.toolBox.indexOf(self.PrePage), QtWidgets.QApplication.translate("MainWindow", "Pre-Process", None, -1))
        self.label_8.setText(QtWidgets.QApplication.translate("MainWindow", "Numb. CPU Cores", None, -1))
        self.label_7.setText(QtWidgets.QApplication.translate("MainWindow", "Overlap", None, -1))
        self.label_10.setText(QtWidgets.QApplication.translate("MainWindow", "Time Step", None, -1))
        self.label_12.setText(QtWidgets.QApplication.translate("MainWindow", "Scale", None, -1))
        self.label_11.setText(QtWidgets.QApplication.translate("MainWindow", "Signal/Noise Method", None, -1))
        self.pro_sig2noise_CB.setItemText(0, QtWidgets.QApplication.translate("MainWindow", "peak2peak", None, -1))
        self.pro_sig2noise_CB.setItemText(1, QtWidgets.QApplication.translate("MainWindow", "peak2mean", None, -1))
        self.pro_sig2noise_CB.setItemText(2, QtWidgets.QApplication.translate("MainWindow", "None", None, -1))
        self.label_4.setText(QtWidgets.QApplication.translate("MainWindow", "Search Area Size", None, -1))
        self.label_9.setText(QtWidgets.QApplication.translate("MainWindow", "Window Size", None, -1))
        self.toolBox.setItemText(self.toolBox.indexOf(self.ProPage), QtWidgets.QApplication.translate("MainWindow", "Process", None, -1))
        self.groupBox_9.setTitle(QtWidgets.QApplication.translate("MainWindow", "Validation", None, -1))
        self.pos_std_LE.setPlaceholderText(QtWidgets.QApplication.translate("MainWindow", "std multiplier", None, -1))
        self.pos_s2n_ratio_LE.setWhatsThis(QtWidgets.QApplication.translate("MainWindow", "<html><head/><body><p><br/></p></body></html>", None, -1))
        self.pos_s2n_ratio_LE.setPlaceholderText(QtWidgets.QApplication.translate("MainWindow", "signal/noise", None, -1))
        self.pos_gv_ulim_LE.setPlaceholderText(QtWidgets.QApplication.translate("MainWindow", "Umin, Umax", None, -1))
        self.pos_std_CB.setText(QtWidgets.QApplication.translate("MainWindow", "Global Std. Deviation", None, -1))
        self.pos_localvelocity_CB.setText(QtWidgets.QApplication.translate("MainWindow", "Local Median", None, -1))
        self.pos_lv_uvdiff_LE.setPlaceholderText(QtWidgets.QApplication.translate("MainWindow", "Udiff, Vdiff", None, -1))
        self.pos_sig2noise_CB.setText(QtWidgets.QApplication.translate("MainWindow", "Signal 2 Noise", None, -1))
        self.pos_globalvelocity_CB.setText(QtWidgets.QApplication.translate("MainWindow", "Global Velocity", None, -1))
        self.pos_lv_kernel_LE.setPlaceholderText(QtWidgets.QApplication.translate("MainWindow", "kernel size", None, -1))
        self.pos_gv_vlim_LE.setPlaceholderText(QtWidgets.QApplication.translate("MainWindow", "Vmin, Vmax", None, -1))
        self.groupBox_10.setTitle(QtWidgets.QApplication.translate("MainWindow", "Vector Corrections", None, -1))
        self.pos_badvector_CB.setText(QtWidgets.QApplication.translate("MainWindow", "Bad Vectors Replacement", None, -1))
        self.pos_bv_niterations_LE.setPlaceholderText(QtWidgets.QApplication.translate("MainWindow", "Num. of max iterations", None, -1))
        self.pos_bv_method_CB.setItemText(0, QtWidgets.QApplication.translate("MainWindow", "localmean", None, -1))
        self.pos_bv_method_CB.setItemText(1, QtWidgets.QApplication.translate("MainWindow", "disk", None, -1))
        self.pos_bv_method_CB.setItemText(2, QtWidgets.QApplication.translate("MainWindow", "distance", None, -1))
        self.pos_bv_kernel_LE.setPlaceholderText(QtWidgets.QApplication.translate("MainWindow", "Kernel size", None, -1))
        self.pos_smth_factor_LE.setPlaceholderText(QtWidgets.QApplication.translate("MainWindow", "smoothing coeff. u, v", None, -1))
        self.pos_smoothing_CB.setText(QtWidgets.QApplication.translate("MainWindow", "Vector Smoothing", None, -1))
        self.pos_fm_LE.setPlaceholderText(QtWidgets.QApplication.translate("MainWindow", "ex. rotCW, flipUD", None, -1))
        self.pos_fieldmanip_CB.setText(QtWidgets.QApplication.translate("MainWindow", "Field Manipulations", None, -1))
        self.label_15.setText(QtWidgets.QApplication.translate("MainWindow", "Output Mode", None, -1))
        self.pos_output_CB.setItemText(0, QtWidgets.QApplication.translate("MainWindow", "simple", None, -1))
        self.pos_output_CB.setItemText(1, QtWidgets.QApplication.translate("MainWindow", "extended", None, -1))
        self.toolBox.setItemText(self.toolBox.indexOf(self.PosPage), QtWidgets.QApplication.translate("MainWindow", "Post-Process", None, -1))
        self.process_savesettings_PB.setText(QtWidgets.QApplication.translate("MainWindow", "Save Settings", None, -1))
        self.Main_tabs.setTabText(self.Main_tabs.indexOf(self.Process), QtWidgets.QApplication.translate("MainWindow", "Process", None, -1))
        self.label_13.setText(QtWidgets.QApplication.translate("MainWindow", "This part of the program is still under development.", None, -1))
        self.Main_tabs.setTabText(self.Main_tabs.indexOf(self.FrequencyAnalysis), QtWidgets.QApplication.translate("MainWindow", "Freq. Analysis", None, -1))
        self.label_6.setText(QtWidgets.QApplication.translate("MainWindow", "This part of the program is still under development.", None, -1))
        self.Main_tabs.setTabText(self.Main_tabs.indexOf(self.ModalAnalysis), QtWidgets.QApplication.translate("MainWindow", "Modal Analysis", None, -1))
        self.menuFile.setTitle(QtWidgets.QApplication.translate("MainWindow", "File", None, -1))
        self.menuHelp.setTitle(QtWidgets.QApplication.translate("MainWindow", "Help", None, -1))
        self.actionLoad_Files.setText(QtWidgets.QApplication.translate("MainWindow", "Load Files", None, -1))
        self.actionExit.setText(QtWidgets.QApplication.translate("MainWindow", "Exit", None, -1))
        self.actionClear_Files.setText(QtWidgets.QApplication.translate("MainWindow", "Clear Files", None, -1))
        self.actionLoad_Raw_Images.setText(QtWidgets.QApplication.translate("MainWindow", "Load Raw Images", None, -1))
        self.actionAbout.setText(QtWidgets.QApplication.translate("MainWindow", "About", None, -1))




# ---
# jupyter:
#   jupytext:
#     text_representation:
#       extension: .py
#       format_name: percent
#       format_version: '1.3'
#       jupytext_version: 1.4.2
#   kernelspec:
#     display_name: Python [conda env:openpiv] *
#     language: python
#     name: conda-env-openpiv-py
# ---

# %% [markdown]
# ## OpenPIV tutorial of all test cases

# %%
from openpiv import tools, process, scaling, validation, filters
import numpy as np
import glob
# %matplotlib inline

# %%
def openpiv_default_run(im1,im2):
    """ default settings for OpenPIV analysis using
    extended_search_area_piv algorithm for two images
    
    Inputs:
        im1,im2 : str,str = path of two image
    """
    frame_a  = tools.imread(im1)
    frame_b  = tools.imread(im2)

    u, v, sig2noise = process.extended_search_area_piv(frame_a.astype(np.int32), 
                                                       frame_b.astype(np.int32), 
                                                       window_size=32, overlap=8, 
                                                       dt=1, search_area_size=64, 
                                                       sig2noise_method='peak2peak' )
    x, y = process.get_coordinates( image_size=frame_a.shape, window_size=32, overlap=8 )
    u, v, mask = validation.sig2noise_val( u, v, sig2noise, threshold = 1.3 )
    u, v = filters.replace_outliers( u, v, method='localmean', max_iter=10, kernel_size=2)
    x, y, u, v = scaling.uniform(x, y, u, v, scaling_factor = 1 )
    tools.save(x, y, u, v, mask, list_of_images[0]+'.txt' )
    fig,ax = tools.display_vector_field(list_of_images[0]+'.txt',on_img=True,image_name=list_of_images[0],scaling_factor=1,ax=None)


# %%
alist_filter = ['jpg','bmp','png','tif','tiff']


# all test cases in /openpiv/examples/
list_of_tests = glob.glob('../test*')
list_of_tests.sort()

list_of_images = []
for test in list_of_tests:
    
    list_of_files = glob.glob(test+'/*.*')
    list_of_files.sort()
    list_of_images = [f for f in list_of_files if f[-3:] in alist_filter]
    
    openpiv_default_run(list_of_images[0],list_of_images[1])




# Proper Orthogonal Decomposition
# By: Pouya Mohtat
# Sep 2020

# This script assumes the data grid to be uniform. If data spacing is not uniform then 'weights' should be included in 
# the data matrix to account for the grid volume at each point...


import os, glob, warnings, time
import numpy as np
import matplotlib.pyplot as plt
from openpivtk import tools
from collections import OrderedDict
from configparser import ConfigParser
#import random


class ModalAnalysis():
    def __init__(self, path, nfiles, pattern):
        self.N = nfiles
        file_list = glob.glob(os.path.join(path, pattern))
        file_list.sort()
        self.file_list = file_list[:nfiles]
        #random.shuffle(self.file_list)
        self.npoints = np.loadtxt(file_list[0], skiprows=1).shape[0]
        self.M = 2 * self.npoints
        self.dir = os.path.join(path, 'Modal Analysis')
        if os.path.isdir(self.dir) == False:
            os.mkdir(self.dir)

    def svd(self, nmode='all'):
        """runs the SVD analysis and returns modes with temporal coefficients and
        their power distribution

        Parameters
        ----------
        nmode : int or 'all', optional
            number of modes to calculate and save. the default is 'all'

        Returns
        -------
        u, a : 2d np.ndarray
            mode array and coefficient array respectively
        
        w, p : 1d np.ndarray
            singular values and power density array respectively
        """

        #find singular values and sort them
        A = self.constructDataMatrix()
        u, w, vh = np.linalg.svd(A, full_matrices=False)
        w, u, p = self.sortEignvalues(w**2, u)
        #calculate the coefficients
        if nmode != 'all':
            u = u[:,0:nmode]
        a = np.matmul(u.T, A)
        self.saveData(u, w, p, a)

        return u, w, a, p

    def snapshot(self, nmode='all'):
        """runs the modal analysis with snapshot method and returns modes with
        temporal coefficients and their power distribution

        Parameters
        ----------
        A : 2d np.ndarray
            field data

        nmode : int or 'all', optional
            number of modes to calculate and save. the default is 'all'

        Returns
        -------
        u, a : 2d np.ndarray
            mode array and coefficient array respectively
        
        w, p : 1d np.ndarray
            singular values and power density array respectively
        """
        #find eignvalues and eignvectors of temporal corelation matrix
        A = self.constructDataMatrix()
        C = np.matmul(A.T, A)
        w, v = np.linalg.eig(C)
        #sort the modes (use sqrt(w) to get power levels reflecting values for matrix A instead of C)
        w, v , p = self.sortEignvalues(w, v)
        #calculate the eign vectors of A
        if nmode == 'all':
            nmode = A.shape[1]    
        u = np.zeros((A.shape[0], nmode))
        for i in range(nmode):
            for j in range(A.shape[1]):
                u[:,i] += v[j,i] * A[:,j]
            u[:,i] /= w[i]
        #calculate coefficients
        a = np.matmul(u.T, A)
        self.saveData(u, w, p, a)
        return u, w, a, p

    def constructDataMatrix(self):
        """reads all files and returns xy info and the data matrix
        """
        A = np.zeros((self.M, self.N))

        #loop to read all files and collect data matrix
        for i in range(self.N):
            data = np.loadtxt(self.file_list[i], skiprows=1)
            A[0:self.M//2, i] = data[:, 7]          # 7th column is u'
            A[self.M//2:self.M, i] = data[:, 8]     # 8th column is v'

        return A

    def sortEignvalues(self, w, u):
        """ Sorts w in descending order and rearranges columns of u accordingly
            also calculates the power density distribution according to eignvalues
        """

        w_sorted = np.sort(w)[::-1]
        arg_sort = np.argsort(w)[::-1]
        u_sorted = np.zeros(u.shape)
        for i, arg in enumerate (arg_sort):
            u_sorted[:,i] = u[:,arg]
        p = w_sorted*100/np.sum(w_sorted)
        
        return w_sorted, u_sorted, p

    def reconstructField(self, nmode='all', nsp='all'):
        """ reconstructs the field using the given number of modes

        Parameters
        ----------
        nmode : int or 'all', optional
            the desired number of modes to use for reconstruction, if set to 'all' then
            all available modes are used. default is 'all'

        nsp : int or 'all', optional
            number of snapshots to reconstruct, if set to 'all' then all snapshots
            are reconstructed, 'all' is the default.

        Returns
        -------
        A_r : 2d np.ndarray
            the reconstructed field
        """
        #read data from saved files
        ap = np.loadtxt(os.path.join(self.dir, 'Coefficients.dat'), skiprows=1)
        a = ap[:,1:].T
        data = np.loadtxt(os.path.join(self.dir, 'Modes.dat'), skiprows=1)
        #check nsp and nmode
        if nsp == 'all':
            nsp = a.shape[1]
        if nsp > a.shape[1]:
            warnings.warn(f'number of snapshots to reconstruct cannot be larger than the original number of snapshots, nsp was set to its maximum possible value: {a.shape[1]}', Warning)
            nsp = a.shape[1]
        if nmode == 'all':
            nmode = a.shape[0]
        if nmode > a.shape[0]:
            warnings.warn(f'number of modes to use cannot be larger than the original number of modes, nmode was set to its maximum possible value: {a.shape[0]}', Warning)
            nmode = a.shape[0]
        # reconstruct the limited u from saved data
        u = np.zeros((self.M, nmode))
        for i in range(nmode):
            u[0:self.M//2,i] = data[:,2*i+2]
            u[self.M//2:self.M,i] = data[:,2*i+3]
        #reconstruct snapshots using u and a
        A_r = np.zeros((self.M, nsp))
        for i in range(nsp):
            for j in range(nmode):
                A_r[:,i] += a[j,i] * u[:,j]
        self.saveData(A_r=A_r)

        return A_r

    def saveData(self, u=None, w=None, p=None, a=None, A_r=None):
        """write data in the "Modal Analysis" directory
        """
        # get grid info
        sample = np.loadtxt(self.file_list[0], skiprows=1)
        nx = len(np.unique(sample[:,0]))
        ny = self.npoints//nx

        if u is not None:
            #saving modes data
            modes = np.zeros((self.npoints, 2*u.shape[1]+2))
            modes[:,0:2] = sample[:,0:2]
            for i in range(u.shape[1]):
                modes[:,2*i+2] = u[0:self.M//2,i]
                modes[:,2*i+3] = u[self.M//2:self.M,i]
            headerline = 'TITLE="Mode Fields" VARIABLES="x", "y", '
            headerline += ', '.join([f'"u{i}", "v{i}"' for i in range(u.shape[1])])
            headerline += f' ZONE I={nx}, J={ny}'
            np.savetxt(os.path.join(self.dir, 'Modes.dat'), modes, fmt='%8.4f', delimiter='\t', header=headerline, comments='')

        if w is not None:
            #saving w and p data
            wp = np.zeros((w.size,4))
            wp[:,0], wp[:,1], wp[:,2], wp[:,3] = range(w.size), w, p, np.cumsum(p)
            headerline = 'TITLE="eignvalues and energy distribution" VARIABLES="mode", "eignvalue", "energy percentage", "cumulative energy percentage"'
            np.savetxt(os.path.join(self.dir, 'Energy Distribution.dat'), wp, fmt='%8.4f', delimiter='\t', header=headerline, comments='')

        if a is not None:
            #saving temporal coefficients
            ap = np.zeros((a.shape[1], a.shape[0]+1), float)
            ap[:,0] = np.arange(a.shape[1]) + 1
            ap[:,1:] = a.T
            headerline = 'TITLE="temporal coefficients" VARIABLES="snapshot", '
            headerline += ', '.join([f'"a{i}"' for i in range(a.shape[0])])
            np.savetxt(os.path.join(self.dir, 'Coefficients.dat'), ap, fmt='%8.4f', delimiter='\t', header=headerline, comments='')

        if A_r is not None:
            #saving the reconstructed flow fields
            A_rr = np.zeros((self.npoints, 4))
            A_rr[:,0:2] = sample[:,0:2]
            for i in range(A_r.shape[1]):
                A_rr[:,2] = A_r[0:self.M//2,i]
                A_rr[:,3] = A_r[self.M//2:self.M,i]
                headerline = f'TITLE="Reconstructed Fields {i+1}" VARIABLES="x", "y", "u", "v" ZONE I={nx}, J={ny}'
                np.savetxt(os.path.join(self.dir, f'ReconstructedField{i+1:06}.dat'), A_rr, fmt='%8.4f', delimiter='\t', header=headerline, comments='')

    @staticmethod
    def saveSettings(exp, analysis, rec, stg_file):
        settings = ConfigParser()
        settings['Experiment'] = exp
        settings['Analysis'] = analysis
        settings['Reconstruction'] = rec
        with open(stg_file, 'w') as fl:
            fl.write('# Modal Analysis Settings:\n\n')
            settings.write(fl)

    @staticmethod
    def loadSettings(stg_file):
        settings = ConfigParser()
        settings.read(stg_file)
        
        return settings['Experiment'], settings['Analysis'], settings['Reconstruction']



#code to test svd/snapshot
if __name__ == "__main__":
    
    t1 = time.time()

    stg_file = r'E:\Temp\Re11_medium\Modal_Settings.dat'
    exp, analysis, rec = OrderedDict(), OrderedDict(), OrderedDict()
    exp, analysis, rec = ModalAnalysis.loadSettings(stg_file)
    for experiment in exp['exp'].split(','):
        for run in exp['run'].split(','):
            experiment = experiment.strip()
            run = run.strip()
            path = os.path.join(exp['dir'], experiment, run, 'Analysis')
            print(f'modal analysis: {experiment}\{run}')
            modal = ModalAnalysis(path, nfiles=int(exp['nf']), pattern=exp['pat'])
            if analysis['st'] == 'True':
                if analysis['mt'] == 'Singular Value Decomposition':
                    print('runing SVD...')
                    modal.svd(nmode=int(analysis['nm']))
                elif analysis['mt'] == 'Snapshots Method':
                    print('runing snapshot method...')
                    modal.snapshot(nmode=int(analysis['nm']))
            if reconst['st'] == 'True':
                print('recontructing flow field...')
                modal.reconstructField(nmode=int(reconst['nm']), nsp=int(reconst['ns']))
    
    t = time.time() - t1
    print(f'Modal Analysis finished in: {t} sec')




#(MIN-env) C:\Users\Asus\Desktop\UI>python C:\Users\Asus\anaconda3\envs\MIN-env\Library\bin\pyside2-uic ImportDialog_Val.ui 
# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'ImportDialog_Val.ui',
# licensing of 'ImportDialog_Val.ui' applies.
#
# Created: Wed Jul 15 09:50:07 2020
#      by: pyside2-uic  running on PySide2 5.13.2
#
# WARNING! All changes made in this file will be lost!

from PySide2 import QtCore, QtGui, QtWidgets

class Ui_ImportDialog_Val(object):
    def setupUi(self, ImportDialog_Val):
        ImportDialog_Val.setObjectName("ImportDialog_Val")
        ImportDialog_Val.resize(680, 425)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(ImportDialog_Val)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.fileSelection_GB = QtWidgets.QGroupBox(ImportDialog_Val)
        self.fileSelection_GB.setObjectName("fileSelection_GB")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.fileSelection_GB)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.gridLayout = QtWidgets.QGridLayout()
        self.gridLayout.setObjectName("gridLayout")
        self.label_7 = QtWidgets.QLabel(self.fileSelection_GB)
        self.label_7.setObjectName("label_7")
        self.gridLayout.addWidget(self.label_7, 1, 0, 1, 1)
        self.folderPath_TB = QtWidgets.QToolButton(self.fileSelection_GB)
        self.folderPath_TB.setObjectName("folderPath_TB")
        self.gridLayout.addWidget(self.folderPath_TB, 0, 4, 1, 1)
        self.label_8 = QtWidgets.QLabel(self.fileSelection_GB)
        self.label_8.setObjectName("label_8")
        self.gridLayout.addWidget(self.label_8, 1, 2, 1, 1)
        self.label_9 = QtWidgets.QLabel(self.fileSelection_GB)
        self.label_9.setObjectName("label_9")
        self.gridLayout.addWidget(self.label_9, 2, 0, 1, 1)
        self.patternA_LE = QtWidgets.QLineEdit(self.fileSelection_GB)
        self.patternA_LE.setPlaceholderText("")
        self.patternA_LE.setObjectName("patternA_LE")
        self.gridLayout.addWidget(self.patternA_LE, 1, 1, 1, 1)
        self.nFiles_LE = QtWidgets.QLineEdit(self.fileSelection_GB)
        self.nFiles_LE.setPlaceholderText("")
        self.nFiles_LE.setObjectName("nFiles_LE")
        self.gridLayout.addWidget(self.nFiles_LE, 2, 1, 1, 1)
        self.folderPath_LE = QtWidgets.QLineEdit(self.fileSelection_GB)
        self.folderPath_LE.setObjectName("folderPath_LE")
        self.gridLayout.addWidget(self.folderPath_LE, 0, 0, 1, 4)
        self.patternB_LE = QtWidgets.QLineEdit(self.fileSelection_GB)
        self.patternB_LE.setPlaceholderText("")
        self.patternB_LE.setObjectName("patternB_LE")
        self.gridLayout.addWidget(self.patternB_LE, 1, 3, 1, 1)
        self.gridLayout_2.addLayout(self.gridLayout, 0, 0, 1, 1)
        self.verticalLayout.addWidget(self.fileSelection_GB)
        self.preprocessSettings_GB = QtWidgets.QGroupBox(ImportDialog_Val)
        self.preprocessSettings_GB.setObjectName("preprocessSettings_GB")
        self.gridLayout_4 = QtWidgets.QGridLayout(self.preprocessSettings_GB)
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.gridLayout_3 = QtWidgets.QGridLayout()
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.windowSize_LE = QtWidgets.QLineEdit(self.preprocessSettings_GB)
        self.windowSize_LE.setObjectName("windowSize_LE")
        self.gridLayout_3.addWidget(self.windowSize_LE, 0, 2, 1, 1)
        self.label_2 = QtWidgets.QLabel(self.preprocessSettings_GB)
        self.label_2.setObjectName("label_2")
        self.gridLayout_3.addWidget(self.label_2, 0, 3, 1, 1)
        self.searchSize_LE = QtWidgets.QLineEdit(self.preprocessSettings_GB)
        self.searchSize_LE.setObjectName("searchSize_LE")
        self.gridLayout_3.addWidget(self.searchSize_LE, 0, 4, 1, 1)
        self.label_3 = QtWidgets.QLabel(self.preprocessSettings_GB)
        self.label_3.setObjectName("label_3")
        self.gridLayout_3.addWidget(self.label_3, 0, 5, 1, 1)
        self.overlap_LE = QtWidgets.QLineEdit(self.preprocessSettings_GB)
        self.overlap_LE.setObjectName("overlap_LE")
        self.gridLayout_3.addWidget(self.overlap_LE, 0, 6, 1, 1)
        self.label_5 = QtWidgets.QLabel(self.preprocessSettings_GB)
        self.label_5.setObjectName("label_5")
        self.gridLayout_3.addWidget(self.label_5, 2, 0, 1, 2)
        self.ncpus_LE = QtWidgets.QLineEdit(self.preprocessSettings_GB)
        self.ncpus_LE.setObjectName("ncpus_LE")
        self.gridLayout_3.addWidget(self.ncpus_LE, 2, 2, 1, 1)
        self.label = QtWidgets.QLabel(self.preprocessSettings_GB)
        self.label.setObjectName("label")
        self.gridLayout_3.addWidget(self.label, 0, 0, 1, 2)
        self.timeStep_LE = QtWidgets.QLineEdit(self.preprocessSettings_GB)
        self.timeStep_LE.setObjectName("timeStep_LE")
        self.gridLayout_3.addWidget(self.timeStep_LE, 1, 2, 1, 1)
        self.label_4 = QtWidgets.QLabel(self.preprocessSettings_GB)
        self.label_4.setObjectName("label_4")
        self.gridLayout_3.addWidget(self.label_4, 1, 0, 1, 2)
        self.label_6 = QtWidgets.QLabel(self.preprocessSettings_GB)
        self.label_6.setObjectName("label_6")
        self.gridLayout_3.addWidget(self.label_6, 1, 3, 1, 1)
        self.sig2noise_CB = QtWidgets.QComboBox(self.preprocessSettings_GB)
        self.sig2noise_CB.setObjectName("sig2noise_CB")
        self.sig2noise_CB.addItem("")
        self.sig2noise_CB.addItem("")
        self.sig2noise_CB.addItem("")
        self.gridLayout_3.addWidget(self.sig2noise_CB, 1, 4, 1, 2)
        self.gridLayout_4.addLayout(self.gridLayout_3, 0, 0, 1, 1)
        self.verticalLayout.addWidget(self.preprocessSettings_GB)
        self.progressBar = QtWidgets.QProgressBar(ImportDialog_Val)
        self.progressBar.setObjectName("progressBar")
        self.verticalLayout.addWidget(self.progressBar)
        self.verticalLayout_2.addLayout(self.verticalLayout)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem)
        self.addFiles_PB = QtWidgets.QPushButton(ImportDialog_Val)
        self.addFiles_PB.setObjectName("addFiles_PB")
        self.horizontalLayout.addWidget(self.addFiles_PB)
        self.cancel_PB = QtWidgets.QPushButton(ImportDialog_Val)
        self.cancel_PB.setObjectName("cancel_PB")
        self.horizontalLayout.addWidget(self.cancel_PB)
        self.verticalLayout_2.addLayout(self.horizontalLayout)

        self.retranslateUi(ImportDialog_Val)
        QtCore.QMetaObject.connectSlotsByName(ImportDialog_Val)

    def retranslateUi(self, ImportDialog_Val):
        ImportDialog_Val.setWindowTitle(QtWidgets.QApplication.translate("ImportDialog_Val", "Add Raw Image Files For Validation", None, -1))
        self.fileSelection_GB.setTitle(QtWidgets.QApplication.translate("ImportDialog_Val", "File Selection", None, -1))
        self.label_7.setText(QtWidgets.QApplication.translate("ImportDialog_Val", "Pattern A", None, -1))
        self.folderPath_TB.setText(QtWidgets.QApplication.translate("ImportDialog_Val", "...", None, -1))
        self.label_8.setText(QtWidgets.QApplication.translate("ImportDialog_Val", "Pattern B", None, -1))
        self.label_9.setText(QtWidgets.QApplication.translate("ImportDialog_Val", "Num.of Files", None, -1))
        self.patternA_LE.setText(QtWidgets.QApplication.translate("ImportDialog_Val", "*LA.TIF", None, -1))
        self.nFiles_LE.setText(QtWidgets.QApplication.translate("ImportDialog_Val", "4", None, -1))
        self.folderPath_LE.setText(QtWidgets.QApplication.translate("ImportDialog_Val", "C:\\Users\\Asus\\Desktop\\UI\\Dummy Data\\Raw Data", None, -1))
        self.folderPath_LE.setPlaceholderText(QtWidgets.QApplication.translate("ImportDialog_Val", "Enter Folder Path Containing Raw Image Files", None, -1))
        self.patternB_LE.setText(QtWidgets.QApplication.translate("ImportDialog_Val", "*LB.TIF", None, -1))
        self.preprocessSettings_GB.setTitle(QtWidgets.QApplication.translate("ImportDialog_Val", "Preprocess Settings", None, -1))
        self.windowSize_LE.setText(QtWidgets.QApplication.translate("ImportDialog_Val", "32", None, -1))
        self.label_2.setText(QtWidgets.QApplication.translate("ImportDialog_Val", "Search Area Size", None, -1))
        self.searchSize_LE.setText(QtWidgets.QApplication.translate("ImportDialog_Val", "32", None, -1))
        self.label_3.setText(QtWidgets.QApplication.translate("ImportDialog_Val", "Overlap", None, -1))
        self.overlap_LE.setText(QtWidgets.QApplication.translate("ImportDialog_Val", "16", None, -1))
        self.label_5.setText(QtWidgets.QApplication.translate("ImportDialog_Val", "Numb. CPU Cores", None, -1))
        self.ncpus_LE.setText(QtWidgets.QApplication.translate("ImportDialog_Val", "2", None, -1))
        self.label.setText(QtWidgets.QApplication.translate("ImportDialog_Val", "Window Size", None, -1))
        self.timeStep_LE.setText(QtWidgets.QApplication.translate("ImportDialog_Val", "0.0015", None, -1))
        self.label_4.setText(QtWidgets.QApplication.translate("ImportDialog_Val", "time step", None, -1))
        self.label_6.setText(QtWidgets.QApplication.translate("ImportDialog_Val", "Signal/Noise Method", None, -1))
        self.sig2noise_CB.setItemText(0, QtWidgets.QApplication.translate("ImportDialog_Val", "peak2peak", None, -1))
        self.sig2noise_CB.setItemText(1, QtWidgets.QApplication.translate("ImportDialog_Val", "peak2mean", None, -1))
        self.sig2noise_CB.setItemText(2, QtWidgets.QApplication.translate("ImportDialog_Val", "None", None, -1))
        self.addFiles_PB.setText(QtWidgets.QApplication.translate("ImportDialog_Val", "Add Files", None, -1))
        self.cancel_PB.setText(QtWidgets.QApplication.translate("ImportDialog_Val", "Cancel", None, -1))




import os
from setuptools import setup, find_packages

# read the contents of your README file
directory = os.path.abspath(os.path.dirname(__file__))
with open(os.path.join(directory, 'README.md')) as fl:
    long_description = fl.read()

setup(
    name = "OpenPIVToolkit",
    version ='0.2.7',
    packages=find_packages(),
    include_package_data=True,
    description='Toolkit for PIV Processing and Post-Processing',
    url="https://github.com/pouya-m/openpiv-toolkit",
    author="Pouya Mohtat",
    author_email="pouya.m67@gmail.com",
    license="GNU General Public License v3",
    long_description=long_description,
    long_description_content_type='text/markdown',
    setup_requires=[
        'setuptools'
    ],
    install_requires=[
        'numpy',            
        'imageio',
        'matplotlib>=3',
        'scikit-image',
        'scipy',
        'PySide2'
    ],
    classifiers = [
        # PyPI-specific version type. The number specified here is a magic constant
        # with no relation to this application's version numbering scheme. *sigh*
        'Development Status :: 4 - Beta',

        # Sublist of all supported Python versions.
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',

        # Sublist of all supported platforms and environments.
        'Environment :: Console',
        'Environment :: MacOS X',
        'Environment :: Win32 (MS Windows)',
        'Environment :: X11 Applications',

        # Miscellaneous metadata.
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Topic :: Scientific/Engineering',
    ]
)




#(MIN-env) C:\Users\Asus\Desktop\UI\ImageOpener>python C:\Users\Asus\anaconda3\envs\MIN-env\Library\bin\pyside2-uic imageopener.ui 
# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'imageopener.ui',
# licensing of 'imageopener.ui' applies.
#
# Created: Sat Oct 31 18:16:36 2020
#      by: pyside2-uic  running on PySide2 5.13.2
#
# WARNING! All changes made in this file will be lost!

from PySide2 import QtCore, QtGui, QtWidgets

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.setEnabled(True)
        MainWindow.resize(800, 600)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(self.centralwidget)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.label = QtWidgets.QLabel(self.centralwidget)
        self.label.setAlignment(QtCore.Qt.AlignCenter)
        self.label.setObjectName("label")
        self.verticalLayout.addWidget(self.label)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.previousPB = QtWidgets.QPushButton(self.centralwidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.previousPB.sizePolicy().hasHeightForWidth())
        self.previousPB.setSizePolicy(sizePolicy)
        self.previousPB.setMinimumSize(QtCore.QSize(20, 0))
        self.previousPB.setMaximumSize(QtCore.QSize(25, 16777215))
        self.previousPB.setObjectName("previousPB")
        self.horizontalLayout.addWidget(self.previousPB)
        self.frame = QtWidgets.QFrame(self.centralwidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.frame.sizePolicy().hasHeightForWidth())
        self.frame.setSizePolicy(sizePolicy)
        self.frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame.setObjectName("frame")
        self.horizontalLayout.addWidget(self.frame)
        self.nextPB = QtWidgets.QPushButton(self.centralwidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.nextPB.sizePolicy().hasHeightForWidth())
        self.nextPB.setSizePolicy(sizePolicy)
        self.nextPB.setMinimumSize(QtCore.QSize(20, 0))
        self.nextPB.setMaximumSize(QtCore.QSize(25, 16777215))
        self.nextPB.setObjectName("nextPB")
        self.horizontalLayout.addWidget(self.nextPB)
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.horizontalLayout_2.addLayout(self.verticalLayout)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 800, 21))
        self.menubar.setObjectName("menubar")
        self.menuFile = QtWidgets.QMenu(self.menubar)
        self.menuFile.setObjectName("menuFile")
        MainWindow.setMenuBar(self.menubar)
        self.actionOpen = QtWidgets.QAction(MainWindow)
        self.actionOpen.setObjectName("actionOpen")
        self.actionExit = QtWidgets.QAction(MainWindow)
        self.actionExit.setObjectName("actionExit")
        self.menuFile.addAction(self.actionOpen)
        self.menuFile.addAction(self.actionExit)
        self.menubar.addAction(self.menuFile.menuAction())

        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        MainWindow.setWindowTitle(QtWidgets.QApplication.translate("MainWindow", "MainWindow", None, -1))
        self.label.setText(QtWidgets.QApplication.translate("MainWindow", "TextLabel", None, -1))
        self.previousPB.setText(QtWidgets.QApplication.translate("MainWindow", "<", None, -1))
        self.nextPB.setText(QtWidgets.QApplication.translate("MainWindow", ">", None, -1))
        self.menuFile.setTitle(QtWidgets.QApplication.translate("MainWindow", "File", None, -1))
        self.actionOpen.setText(QtWidgets.QApplication.translate("MainWindow", "Open", None, -1))
        self.actionExit.setText(QtWidgets.QApplication.translate("MainWindow", "Exit", None, -1))




"""This module contains image processing routines that improve
images prior to PIV processing."""

__licence_ = """
Copyright (C) 2011  www.openpiv.net
This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.
This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""

def piv():
    """
    Simplest PIV run on the pair of images using default settings

    piv(im1,im2) will create a tmp.vec file with the vector filed in pix/dt (dt=1) from 
    two images, im1,im2 provided as full path filenames (TIF is preferable, whatever imageio can read)

    """



    import imageio
    import numpy as np
    import matplotlib.pyplot as plt

    from openpivtk import process
    import pkg_resources as pkg

    import numpy as np

    import matplotlib.animation as animation




    # if im1 is None and im2 is None:
    im1 = pkg.resource_filename('openpivtk','examples/test5/frame_a.tif')
    im2 = pkg.resource_filename('openpivtk','examples/test5/frame_b.tif')


    frame_a = imageio.imread(im1)
    frame_b = imageio.imread(im2)
    
    frame_a[0:32,512-32:] = 255


    images = []
    images.extend([frame_a,frame_b])


    fig,ax  = plt.subplots()

    # ims is a list of lists, each row is a list of artists to draw in the
    # current frame; here we are just animating one artist, the image, in
    # each frame
    ims = []
    for i in range(2):
        im = ax.imshow(images[i%2], animated=True, cmap=plt.cm.gray)
        ims.append([im])

    _ = animation.ArtistAnimation(fig, ims, interval=200, blit=False, repeat_delay=0)
    plt.show()

    # import os
    
    u, v = process.extended_search_area_piv(frame_a.astype(np.int32),frame_b.astype(np.int32),window_size=32,overlap=16)
    x, y = process.get_coordinates( image_size=frame_a.shape, 
                               window_size=32, overlap=16)

    fig,ax = plt.subplots(1,2,figsize=(11,8))
    ax[0].imshow(frame_a,cmap=plt.get_cmap('gray'),alpha=0.8,origin='upper')
    ax[0].quiver(x,y,u,v,scale=50,color='r')
    
    ax[1].quiver(x,y,u,v,scale=50,color='b')
    ax[1].set_aspect(1.1)
    ax[1].invert_yaxis()
    plt.show()

    return x,y,u,v
    
